@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Krinkle
  * @author Omnipaedista
  * @author Svetko
  * @author Wolliger Mensch
@@ -92,7 +93,7 @@ $messages = array(
 'monday'        => 'понедѣл҄ьникъ',
 'tuesday'       => 'въторьникъ',
 'wednesday'     => 'срѣда',
-'thursday'      => 'четврьтъкъ',
+'thursday'      => 'чєтврьтъкъ',
 'friday'        => 'пѧтъкъ',
 'saturday'      => 'сѫбота',
 'sun'           => 'н҃д',
@@ -147,16 +148,43 @@ $messages = array(
 
 'linkprefix' => '/^(.*?)(„|«)$/sD',
 
-'about'          => 'опьса́ниѥ',
+'about'         => 'опьса́ниѥ',
+'article'       => 'члѣ́нъ',
+'moredotdotdot' => 'вѧ́щє ···',
+'mypage'        => 'моꙗ́ страни́ца',
+'mytalk'        => 'моꙗ́ бєсѣ́да',
+'navigation'    => 'пла́ваниѥ',
+'and'           => '&#32;и',
+
+# Cologne Blue skin
 'qbedit'         => 'испра́ви',
 'qbpageoptions'  => 'си страни́ца',
 'qbmyoptions'    => 'моꙗ́ страни́цѧ',
 'qbspecialpages' => 'наро́чьнꙑ страни́цѧ',
-'moredotdotdot'  => 'вѧ́щє ···',
-'mypage'         => 'моꙗ́ страни́ца',
-'mytalk'         => 'моꙗ́ бєсѣ́да',
-'navigation'     => 'пла́ваниѥ',
-'and'            => '&#32;и',
+
+# Vector skin
+'vector-action-delete'       => 'поничьжє́ниѥ',
+'vector-action-move'         => 'прѣимєнова́ниѥ',
+'vector-action-protect'      => 'ꙁабранѥ́ниѥ',
+'vector-action-unprotect'    => 'поущє́ниѥ',
+'vector-namespace-category'  => 'катигорі́ꙗ',
+'vector-namespace-help'      => 'по́мощь',
+'vector-namespace-image'     => 'дѣ́ло',
+'vector-namespace-main'      => 'члѣ́нъ',
+'vector-namespace-media'     => 'срѣ́дьства',
+'vector-namespace-mediawiki' => 'напьса́ниѥ',
+'vector-namespace-project'   => 'съвѣ́тъ',
+'vector-namespace-special'   => 'наро́чьна',
+'vector-namespace-talk'      => 'бєсѣ́да',
+'vector-namespace-template'  => 'обраꙁь́ць',
+'vector-namespace-user'      => 'по́льꙃєватєл҄ь',
+'vector-view-create'         => 'сътворѥ́ниѥ',
+'vector-view-edit'           => 'испра́ви',
+'vector-view-history'        => 'їсторі́ꙗ',
+'vector-view-view'           => 'чьтѥ́ниѥ',
+'vector-view-viewsource'     => 'страни́цѧ исто́чьнъ о́браꙁъ',
+'actions'                    => 'дѣ́иства',
+'namespaces'                 => 'имє́нъ просто́рꙑ',
 
 'errorpagetitle'   => 'блаꙁна',
 'tagline'          => '{{grammar:genitive|{{SITENAME}}}} страни́ца',
@@ -189,7 +217,8 @@ $messages = array(
 'otherlanguages'   => 'ДРОУГꙐ́ ѨꙀꙐКꙐ́',
 'redirectedfrom'   => '(прѣнаправлѥ́ниѥ о́тъ ⁖ $1 ⁖)',
 'redirectpagesub'  => 'прѣнаправлѥ́ниѥ',
-'lastmodifiedat'   => 'страни́цѧ послѣ́дьнꙗ мѣ́на сътворѥна́ $2 · $1 бѣ ⁙', # $1 date, $2 time
+'lastmodifiedat'   => 'страни́цѧ послѣ́дьнꙗ мѣ́на сътворѥна́ $2 · $1 бѣ ⁙',
+'jumpto'           => 'прѣиди́ къ :',
 'jumptonavigation' => 'пла́ваниѥ',
 'jumptosearch'     => 'иска́ниѥ',
 
@@ -208,6 +237,7 @@ $messages = array(
 'portal'               => 'обьщє́ниꙗ съвѣ́тъ',
 'portal-url'           => 'Project:Обьщє́ниꙗ съвѣ́тъ',
 
+'youhavenewmessages'  => '$1 тєбѣ напьсанꙑ сѫтъ ($2)',
 'newmessageslink'     => 'но́ви напь́саниꙗ',
 'newmessagesdifflink' => 'послѣ́дьнꙗ мѣ́на',
 'editsection'         => 'испра́ви',
@@ -240,14 +270,13 @@ $messages = array(
 'viewsourcefor' => '$1 дѣлꙗ',
 
 # Login and logout pages
-'logouttitle'             => 'ис̾хо́дъ',
-'loginpagetitle'          => 'Въходъ',
 'yourname'                => 'твоѥ́ и́мѧ',
 'yourpassword'            => 'Таино слово напиши',
 'yourpasswordagain'       => 'Опакы таиноѥ слово напиши',
 'login'                   => 'Въниди',
 'nav-login-createaccount' => 'въниди / съꙁи́жди си мѣ́сто',
 'userlogin'               => 'въниди / съꙁи́жди си мѣ́сто',
+'userloginnocreate'       => 'въниди',
 'logout'                  => 'ис̾хо́дъ',
 'userlogout'              => 'ис̾хо́дъ',
 'nologinlink'             => 'съꙁи́жди си мѣ́сто',
@@ -255,20 +284,15 @@ $messages = array(
 'gotaccount'              => "Мѣсто ти ѥстъ ли? '''$1'''.",
 'gotaccountlink'          => 'Въниди',
 'userexists'              => 'сѫщє по́льꙃєватєлꙗ и́мѧ пьса ⁙ ино иꙁобрѧщи',
-'username'                => 'по́льꙃєватєлꙗ и́мѧ :',
-'uid'                     => 'по́льꙃєватєлꙗ число́ :',
-'yourrealname'            => 'и́стиньно и́мѧ :',
-'yourlanguage'            => 'ѩꙁꙑ́къ :',
-'yournick'                => 'аѵто́графъ :',
-'gender-male'             => 'мѫжъ',
-'gender-female'           => 'жєна',
 'loginerror'              => 'въхода блаꙁна',
 'accountcreated'          => 'мѣ́сто сътворєно́ ѥ́стъ',
 'loginlanguagelabel'      => 'ѩꙁꙑ́къ : $1',
 
 # Password reset dialog
-'oldpassword' => 'старо таино слово :',
-'newpassword' => 'ново таино слово :',
+'resetpass'                 => 'таина словєсє иꙁмѣнѥ́ниѥ',
+'oldpassword'               => 'старо таино слово :',
+'newpassword'               => 'ново таино слово :',
+'resetpass-submit-loggedin' => 'таина словєсє иꙁмѣнѥ́ниѥ',
 
 # Edit page toolbar
 'link_sample'    => 'съвѧ́ꙁи и́мѧ',
@@ -277,18 +301,26 @@ $messages = array(
 'sig_tip'        => 'твои аѵто́графъ и нꙑ́нѣшьна врѣ́мѧ и дьнь',
 
 # Edit pages
-'summary'            => 'опьса́ниѥ :',
-'minoredit'          => 'ма́лаꙗ мѣ́на',
-'watchthis'          => 'си страни́цѧ блюдє́ниѥ',
-'savearticle'        => 'съхранѥ́ниѥ',
-'loginreqlink'       => 'Въниди',
-'newarticle'         => '(но́въ)',
-'clearyourcache'     => 'НАРОЧИ́ТО: По съхранѥ́нии мо́жєши обити́ своѥго́ съмотри́ла съхра́нъ да ви́дѣлъ би мѣ́нꙑ ⁙ Mozilla ли Firefox ли Safari ли жьмꙑ́и Shift а мꙑ́шиѭ жьми́ Reload и́ли жьми́ Ctrl-Shift-R (Cmd-Shift-R вън Apple Mac)  ⁙ Konqueror ли жьми́ кро́мѣ Reload и́ли F5 ⁙ О́пєрꙑ по́льꙃєватєльмъ мо́жєть бꙑ́ти ноужда́ пльнѣ пони́чьжити и́хъ съмотри́ла съхра́нъ въ Tools > Preferences ⁙ IE ли жьмꙑ́и Ctrl а мꙑ́шиѭ жьми́ Refresh и́ли жьми́ Ctrl-F5',
-'note'               => "'''НАРОЧИ́ТО:'''",
-'editing'            => 'исправлѥ́ниѥ: $1',
-'editingsection'     => 'исправлѥ́ниѥ ⁖ $1 ⁖ (чѧ́сть)',
-'templatesused'      => 'сѥѩ страни́цѧ с҄и обраꙁьци́ по́льꙃоуѭтъ сѧ сѫ́тъ :',
-'template-protected' => '(ꙁабранєно ѥ́стъ)',
+'summary'                    => 'опьса́ниѥ :',
+'minoredit'                  => 'ма́лаꙗ мѣ́на',
+'watchthis'                  => 'си страни́цѧ блюдє́ниѥ',
+'savearticle'                => 'съхранѥ́ниѥ',
+'showpreview'                => 'мѣ́нꙑ поꙁьрѣ́ниѥ (бєꙁ съхранѥ́ниꙗ)',
+'loginreqlink'               => 'Въниди',
+'newarticle'                 => '(но́въ)',
+'noarticletext'              => 'нꙑнѣ с̑ьдє́ ничєсожє нє напьсано ѥ́стъ ⁙
+[[Special:Search/{{PAGENAME}}|си страни́цѧ имѧ искати]] дроугꙑ страни́цѧ ·
+<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} съвѧ́ꙁанꙑ їсторі́ѩ видѣти] ·
+или [{{fullurl:{{FULLPAGENAME}}|action=edit}} ѭ́жє исправити]</span> можєши',
+'noarticletext-nopermission' => 'нꙑнѣ с̑ьдє́ ничєсожє нє напьсано ѥ́стъ ⁙
+[[Special:Search/{{PAGENAME}}|си страни́цѧ имѧ искати]] дроугы страни́цѧ или
+<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} съвѧ́ꙁанꙑ їсторі́ѩ видѣти]</span> можєши',
+'clearyourcache'             => 'НАРОЧИ́ТО: По съхранѥ́нии мо́жєши обити́ своѥго́ съмотри́ла съхра́нъ да ви́дѣлъ би мѣ́нꙑ ⁙ Mozilla ли Firefox ли Safari ли жьмꙑ́и Shift а мꙑ́шиѭ жьми́ Reload и́ли жьми́ Ctrl-Shift-R (Cmd-Shift-R вън Apple Mac)  ⁙ Konqueror ли жьми́ кро́мѣ Reload и́ли F5 ⁙ О́пєрꙑ по́льꙃєватєльмъ мо́жєть бꙑ́ти ноужда́ пльнѣ пони́чьжити и́хъ съмотри́ла съхра́нъ въ Tools > Preferences ⁙ IE ли жьмꙑ́и Ctrl а мꙑ́шиѭ жьми́ Refresh и́ли жьми́ Ctrl-F5',
+'note'                       => "'''НАРОЧИ́ТО:'''",
+'editing'                    => 'исправлѥ́ниѥ: $1',
+'editingsection'             => 'исправлѥ́ниѥ ⁖ $1 ⁖ (чѧ́сть)',
+'templatesused'              => 'сѥѩ страни́цѧ {{PLURAL:$1|сь обраꙁь́ць по́льꙃоуѥтъ сѧ ѥ́стъ|с҄и обраꙁьца́ по́льꙃоуѭтъ сѧ ѥстє́|с҄и обраꙁьци́ по́льꙃоуѭтъ сѧ сѫ́тъ}} :',
+'template-protected'         => '(ꙁабранєно ѥ́стъ)',
 
 # History pages
 'viewpagelogs' => 'си страни́цѧ їсторі́ѩ',
@@ -296,44 +328,56 @@ $messages = array(
 'last'         => 'пс҃лд',
 'page_first'   => 'прь́ва страни́ца',
 'page_last'    => 'послѣ́дьнꙗ страни́ца',
-'deletedrev'   => '[поничьжєно ѥ́стъ]',
 'histlast'     => 'послѣ́дьнꙗ',
 'historyempty' => '(поу́сто)',
 
 # Revision feed
 'history-feed-title'          => 'мѣ́нъ їсторі́ꙗ',
-'history-feed-item-nocomment' => '$1 при $2', # user at time
+'history-feed-item-nocomment' => '$1 при $2',
 
 # Revision deletion
-'revdelete-uname' => 'по́льꙃєватєлꙗ и́мѧ',
-
-# Diffs
-'diff-with'       => '&#32;съ $1 $2',
-'diff-with-final' => '&#32;и $1 $2',
+'rev-delundel'               => 'каꙁаниѥ / съкрꙑ́тиѥ',
+'rev-showdeleted'            => 'ви́ждь',
+'revdelete-show-file-submit' => 'да',
+'revdelete-radio-set'        => 'да',
+'revdelete-radio-unset'      => 'нѣ́тъ',
+'revdelete-uname'            => 'по́льꙃєватєлꙗ и́мѧ',
 
 # Search results
-'searchresults'                  => 'иска́ниꙗ ито́гъ',
-'searchresults-title'            => 'иска́ниꙗ ⁖ $1 ⁖ ито́гъ',
+'searchresults'                  => 'иска́ниꙗ слѣдьствиѥ',
+'searchresults-title'            => 'иска́ниꙗ ⁖ $1 ⁖ слѣдьствиѥ',
+'viewprevnext'                   => 'виждь ($1 {{int:pipe-separator}} $2) ($3)',
 'searchmenu-new'                 => "'''страни́цѫ ⁖ [[:$1]] ⁖ сътвори́ти мо́жєши'''",
 'searchhelp-url'                 => 'Help:Ката́логъ',
-'searchprofile-images'           => 'дѣ́ла',
+'searchprofile-articles'         => 'члѣ́ни',
+'searchprofile-images'           => 'дѣла́',
 'searchprofile-everything'       => 'вьсѩ́ страни́цѧ',
 'searchprofile-articles-tooltip' => 'ищи въ $1',
 'search-result-size'             => '$1 ({{PLURAL:$2|$2 сло́во|$2 сло́ва|$2 словє́съ}})',
 'search-redirect'                => '(прѣнаправлє́ниѥ $1)',
 'search-section'                 => '(чѧ́сть $1)',
 'search-interwiki-caption'       => 'ро́дьствьна опꙑтьствова́ниꙗ',
+'search-interwiki-more'          => '(вѧ́щє)',
 'searchall'                      => 'вьсꙗ́',
 'powersearch'                    => 'ищи́',
 
 # Preferences page
 'preferences'         => 'строи',
 'mypreferences'       => 'мои строи',
+'changepassword'      => 'таина словєсє иꙁмѣнѥ́ниѥ',
 'prefs-rc'            => 'послѣ́дьнѩ мѣ́нꙑ',
 'prefs-watchlist'     => 'блюдє́ниꙗ',
+'prefs-resetpass'     => 'таина словєсє иꙁмѣнѥ́ниѥ',
 'searchresultshead'   => 'иска́ниѥ',
 'prefs-searchoptions' => 'иска́ниꙗ строи́',
-'files'               => 'дѣла́',
+'prefs-files'         => 'дѣла́',
+'username'            => 'по́льꙃєватєлꙗ и́мѧ :',
+'uid'                 => 'по́льꙃєватєлꙗ число́ :',
+'yourrealname'        => 'и́стиньно и́мѧ :',
+'yourlanguage'        => 'ѩꙁꙑ́къ :',
+'yournick'            => 'аѵто́графъ :',
+'gender-male'         => 'мѫжъ',
+'gender-female'       => 'жєна',
 
 # Groups
 'group-user'       => 'по́льꙃєватєлє',
@@ -358,25 +402,33 @@ $messages = array(
 'action-edit' => 'си страни́цѧ исправлє́ниѥ',
 
 # Recent changes
-'nchanges'        => '$1 {{PLURAL:$1|мѣ́на|мѣ́нꙑ|мѣ́нъ}}',
-'recentchanges'   => 'послѣ́дьнѩ мѣ́нꙑ',
-'rcnote'          => "нижѣ {{PLURAL:$1|'''1''' послѣ́дьнѭ мѣ́нѫ|'''$1''' послѣ́дьни мѣ́нꙑ|'''$1''' послѣ́дьнъ мѣ́нъ|'''$1''' послѣ́дьнъ мѣ́нъ}} ꙁа {{PLURAL:$2|дьнь|'''$2''' дьнꙗ|'''$2''' дьнъ|'''$2''' дьнъ}} · ꙗко нꙑнѣ $5 · $4 лѣ́та",
-'rcshowhideminor' => '$1 ма́лꙑ мѣ́нꙑ',
-'rcshowhidebots'  => '$1 аѵтома́тъ',
-'rcshowhideliu'   => '$1 по́льꙃєватєлъ · ѩжє съꙁижьдє сѥ мѣ́сто · мѣ́нꙑ',
-'rcshowhideanons' => '$1 анонѷмьнъ по́льꙃєватєлъ мѣ́нꙑ',
-'rcshowhidemine'  => '$1 моꙗ́ мѣ́нꙑ',
-'diff'            => 'ра҃ꙁн',
-'hist'            => 'їс҃т',
-'hide'            => 'съкрꙑи',
-'show'            => 'ви́ждь',
-'minoreditletter' => 'м҃л',
-'newpageletter'   => 'н҃в',
-'boteditletter'   => 'а҃ѵ',
+'nchanges'                    => '$1 {{PLURAL:$1|мѣ́на|мѣ́нꙑ|мѣ́нъ}}',
+'recentchanges'               => 'послѣ́дьнѩ мѣ́нꙑ',
+'recentchanges-legend'        => 'послѣдьн҄ь мѣнъ строи',
+'recentchangestext'           => 'с҄ьдє послѣдьнѩ мѣнꙑ сѥѩ викиопꙑтьствованиꙗ видѣти можєши',
+'recentchanges-label-newpage' => 'по сѥи мѣнꙑ нова страница сътворѥна ѥстъ',
+'recentchanges-label-minor'   => 'ма́лаꙗ мѣ́на',
+'recentchanges-label-bot'     => 'сѭ мѣноу аѵтоматъ сътворихъ',
+'rcnote'                      => "нижѣ {{PLURAL:$1|'''1''' послѣ́дьнѭ мѣ́нѫ|'''$1''' послѣ́дьни мѣ́нꙑ|'''$1''' послѣ́дьнъ мѣ́нъ|'''$1''' послѣ́дьнъ мѣ́нъ}} ꙁа {{PLURAL:$2|дьнь|'''$2''' дьнꙗ|'''$2''' дьнъ|'''$2''' дьнъ}} · ꙗко нꙑнѣ $5 · $4 лѣ́та",
+'rcshowhideminor'             => '$1 ма́лꙑ мѣ́нꙑ',
+'rcshowhidebots'              => '$1 аѵтома́тъ',
+'rcshowhideliu'               => '$1 по́льꙃєватєлъ · ѩжє съꙁижьдє сѥ мѣ́сто · мѣ́нꙑ',
+'rcshowhideanons'             => '$1 анѡнѷмьнъ по́льꙃєватєлъ мѣ́нꙑ',
+'rcshowhidemine'              => '$1 моꙗ́ мѣ́нꙑ',
+'rclinks'                     => '$1 послѣдьн҄ь  мѣнъ · ѩжє $2 послѣдьни дьни створѥнꙑ сѫтъ · каꙁаниѥ<br />$3',
+'diff'                        => 'ра҃ꙁн',
+'hist'                        => 'їс҃т',
+'hide'                        => 'съкрꙑи',
+'show'                        => 'ви́ждь',
+'minoreditletter'             => 'м҃л',
+'newpageletter'               => 'н҃в',
+'boteditletter'               => 'а҃ѵ',
 
 # Recent changes linked
-'recentchangeslinked'      => 'съвѧ́ꙁанꙑ страни́цѧ',
-'recentchangeslinked-page' => 'страни́цѧ и́мѧ :',
+'recentchangeslinked'         => 'съвѧ́ꙁанꙑ страни́цѧ',
+'recentchangeslinked-feed'    => 'съвѧ́ꙁанꙑ страни́цѧ',
+'recentchangeslinked-toolbox' => 'съвѧ́ꙁанꙑ страни́цѧ',
+'recentchangeslinked-page'    => 'страни́цѧ и́мѧ :',
 
 # Upload
 'upload'            => 'положє́ниѥ дѣ́ла',
@@ -390,6 +442,9 @@ $messages = array(
 'uploadedimage'     => '⁖ [[$1]] ⁖ положє́нъ ѥ́стъ',
 'watchthisupload'   => 'си дѣ́ла блюдє́ниѥ',
 
+'license'        => 'прощєниѥ :',
+'license-header' => 'прощєниѥ',
+
 # Special:ListFiles
 'imgfile'        => 'дѣ́ло',
 'listfiles'      => 'дѣ́лъ ката́логъ',
@@ -398,12 +453,14 @@ $messages = array(
 'listfiles_size' => 'мѣ́ра',
 
 # File description page
+'file-anchor-link'   => 'ви́дъ',
 'filehist'           => 'дѣ́ла їсторі́ꙗ',
 'filehist-deleteone' => 'поничьжє́ниѥ',
 'filehist-current'   => 'нꙑнѣщьн҄ь о́браꙁъ',
 'filehist-datetime'  => 'дьнь / врѣ́мѧ',
 'filehist-user'      => 'по́льꙃєватєл҄ь',
 'imagelinks'         => 'дѣ́ла съвѧ́ꙁи',
+'sharedupload'       => 'сѥ дѣ́ло въ $1 съхранѥ́но ѥ́стъ дѣ́ла · ѥгожє дроугꙑ́ опꙑтьствова́ниѩ по́льꙃєвати мо́гѫтъ',
 
 # File deletion
 'filedelete-submit' => 'поничьжє́ниѥ',
@@ -412,6 +469,9 @@ $messages = array(
 'mimetype' => 'MIME тѵ́пъ :',
 'download' => 'поѩ́ти',
 
+# List redirects
+'listredirects' => 'прѣнаправлѥ́ниꙗ',
+
 # Random page
 'randompage' => 'страни́ца въ нєꙁаа́пѫ',
 
@@ -431,12 +491,13 @@ $messages = array(
 'disambiguations'     => 'мъногосъмꙑ́слиꙗ',
 'disambiguationspage' => 'Template:мъногосъмꙑ́слиѥ',
 
-'brokenredirects-edit'   => '(испра́ви)',
-'brokenredirects-delete' => '(поничьжє́ниѥ)',
+'brokenredirects-edit'   => 'испра́ви',
+'brokenredirects-delete' => 'поничьжє́ниѥ',
 
 # Miscellaneous special pages
 'nbytes'            => '$1 {{PLURAL:$1|ба́итъ|ба́ита|ба́итъ}}',
 'nlinks'            => '$1 {{PLURAL:$1|съвѧ́ꙁь|съвѧ́ꙁѧ|съвѧ́ꙁи}}',
+'shortpages'        => 'кратъкꙑ страни́цѧ',
 'listusers'         => 'по́льꙃєватєлъ ката́логъ',
 'newpages'          => 'но́ви члѣ́ни',
 'newpages-username' => 'по́льꙃєватєлꙗ и́мѧ :',
@@ -467,6 +528,7 @@ $messages = array(
 'deletedcontributions-title' => 'пони́чьжєнꙑ добродѣꙗ́ниꙗ',
 
 # Special:LinkSearch
+'linksearch'    => 'вънѣщьнѩ съвѧ́ꙁи',
 'linksearch-ok' => 'ищи́',
 
 # Special:ListUsers
@@ -481,14 +543,16 @@ $messages = array(
 'emailuser' => 'посъли єпїстолѫ',
 
 # Watchlist
-'watchlist'      => 'моꙗ́ блюдє́ниꙗ',
-'mywatchlist'    => 'Моꙗ́ блюдє́ниꙗ',
-'watchlistfor'   => "(по́льꙃєватєлꙗ и́мѧ '''$1''' ѥ́стъ)",
-'addedwatchtext' => "страни́ца ⁖ [[:$1]] ⁖ нꙑнѣ по́дъ твоимь [[Special:Watchlist|блюдє́ниѥмь]] ѥ́стъ ⁙
+'watchlist'        => 'моꙗ́ блюдє́ниꙗ',
+'mywatchlist'      => 'моꙗ́ блюдє́ниꙗ',
+'watchlistfor'     => "(по́льꙃєватєлꙗ и́мѧ '''$1''' ѥ́стъ)",
+'addedwatch'       => 'страни́ца нꙑнѣ по́дъ твоимь блюдє́ниѥмь ѥ́стъ',
+'addedwatchtext'   => "страни́ца ⁖ [[:$1]] ⁖ нꙑнѣ по́дъ твоимь [[Special:Watchlist|блюдє́ниѥмь]] ѥ́стъ ⁙
 всꙗ ѥѩ и ѥѩжє бєсѣдꙑ мѣ́нꙑ страни́цѧ ⁖ [[Special:Watchlist|моꙗ́ блюдє́ниꙗ]] ⁖ покаꙁанꙑ сѫ́тъ и  [[Special:RecentChanges|послѣ́дьнъ мѣ́нъ]] ката́лоꙃѣ '''чрьнꙑимъ''' сѧ авлꙗѭтъ",
-'watch'          => 'блюдє́ниѥ',
-'watchthispage'  => 'си страни́цѧ блюдє́ниѥ',
-'unwatch'        => 'оста́ви блюдє́ниѥ',
+'removedwatchtext' => 'страни́ца ⁖ [[:$1]] ⁖ нꙑнѣ твоѥго [[Special:Watchlist|блюдє́ниꙗ]] иꙁнєсєна ѥ́стъ',
+'watch'            => 'блюдє́ниѥ',
+'watchthispage'    => 'си страни́цѧ блюдє́ниѥ',
+'unwatch'          => 'оста́ви блюдє́ниѥ',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'блюдє́ниѥ ...',
@@ -502,7 +566,7 @@ $messages = array(
 'excontentauthor' => "вънѫтри́ бѣ : '$1' (и послѣ́дьн҄ии дѣ́тєл҄ь бѣ '[[Special:Contributions/$2|$2]]')",
 'delete-legend'   => 'поничьжє́ниѥ',
 'actioncomplete'  => 'дѣ́иство сътворєно́ ѥ́стъ',
-'deletedtext'     => 'страни́ца ⁖ <nowiki>$1</nowiki> ⁖ поничьжєна ѥ́стъ ⁙ 
+'deletedtext'     => 'страни́ца ⁖ <nowiki>$1</nowiki> ⁖ поничьжєна ѥ́стъ ⁙
 виждь ⁖ $2 ⁖ послѣ́дьнъ поничьжє́ниѩ дѣлꙗ́',
 'deletedarticle'  => '⁖ [[$1]] ⁖ поничьжє́нъ ѥ́стъ',
 'dellogpage'      => 'поничьжє́ниꙗ їсторі́ꙗ',
@@ -534,6 +598,9 @@ $messages = array(
 'uctop'               => '(послѣ́дьнꙗ мѣ́на)',
 
 'sp-contributions-blocklog' => 'ꙁаграждє́ниꙗ їсторі́ꙗ',
+'sp-contributions-deleted'  => 'пони́чьжєнꙑ добродѣꙗ́ниꙗ',
+'sp-contributions-talk'     => 'бєсѣ́да',
+'sp-contributions-username' => 'IP число или по́льꙃєватєлꙗ и́мѧ :',
 'sp-contributions-submit'   => 'ищи́',
 
 # What links here
@@ -547,49 +614,55 @@ $messages = array(
 
 # Block/unblock
 'blockip'            => 'ꙁагради́ по́льꙃєватєл҄ь',
+'ipadressorusername' => 'IP число или по́льꙃєватєлꙗ и́мѧ :',
 'ipblocklist-submit' => 'иска́ниѥ',
 'blocklink'          => 'ꙁагради́',
 'contribslink'       => 'добродѣꙗ́ниꙗ',
 'blocklogpage'       => 'ꙁаграждє́ниꙗ їсторі́ꙗ',
 
 # Move page
-'move-page'        => 'прѣимєнова́ниѥ ⁖ $1 ⁖',
-'move-page-legend' => 'страни́цѧ прѣимєнова́ниѥ',
-'movearticle'      => 'страни́ца :',
-'newtitle'         => 'но́во и́мѧ :',
-'move-watch'       => 'си страни́цѧ блюдє́ниѥ',
-'movepagebtn'      => 'прѣимєнова́ниѥ',
-'pagemovedsub'     => 'прѣимєнова́ниѥ сътворѥно́ ѥ́стъ',
-'movepage-moved'   => "'''⁖ $1 ⁖ нарєчє́нъ ⁖ $2⁖ ѥ́стъ'''", # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'movedto'          => 'прѣимєновано въ',
-'movetalk'         => 'си страни́цѧ бєсѣ́дꙑ прѣимєнова́ниѥ',
-'1movedto2'        => '⁖ [[$1]] ⁖ нарєчє́нъ ⁖ [[$2]] ⁖ ѥ́стъ',
-'1movedto2_redir'  => '[[$1]] нарєчє́нъ [[$2]] врьхоу́ прѣнаправлѥ́ниꙗ ѥ́стъ.',
-'movelogpage'      => 'прѣимєнова́ниꙗ їсторі́ꙗ',
+'move-page'               => 'прѣимєнова́ниѥ ⁖ $1 ⁖',
+'move-page-legend'        => 'страни́цѧ прѣимєнова́ниѥ',
+'movearticle'             => 'страни́ца :',
+'newtitle'                => 'но́во и́мѧ :',
+'move-watch'              => 'си страни́цѧ блюдє́ниѥ',
+'movepagebtn'             => 'прѣимєнова́ниѥ',
+'pagemovedsub'            => 'прѣимєнова́ниѥ сътворѥно́ ѥ́стъ',
+'movepage-moved'          => "'''⁖ $1 ⁖ нарєчє́нъ ⁖ $2⁖ ѥ́стъ'''",
+'movepage-moved-redirect' => 'прѣнаправлѥ́ниѥ сътворѥно́ бѣ',
+'movedto'                 => 'прѣимєновано въ',
+'movetalk'                => 'си страни́цѧ бєсѣ́дꙑ прѣимєнова́ниѥ',
+'1movedto2'               => '⁖ [[$1]] ⁖ нарєчє́нъ ⁖ [[$2]] ⁖ ѥ́стъ',
+'1movedto2_redir'         => '[[$1]] нарєчє́нъ [[$2]] врьхоу́ прѣнаправлѥ́ниꙗ ѥ́стъ.',
+'movelogpage'             => 'прѣимєнова́ниꙗ їсторі́ꙗ',
 
 # Namespace 8 related
 'allmessages'     => 'сѷсти́мьнꙑ напьса́ниꙗ',
 'allmessagesname' => 'и́мѧ',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'      => 'твоꙗ́ по́льꙃєватєл҄ьска страни́ца',
-'tooltip-pt-mytalk'        => 'твоꙗ́ бєсѣ́дꙑ страни́ца',
-'tooltip-pt-preferences'   => 'твоꙗ́ строи',
-'tooltip-pt-mycontris'     => 'твоꙗ́ добродѣꙗ́ниѩ ката́логъ',
-'tooltip-pt-logout'        => 'ис̾хо́дъ',
-'tooltip-ca-viewsource'    => 'си страни́ца ꙁабранєна́ ѥ́стъ ⁙
+'tooltip-pt-userpage'            => 'твоꙗ́ по́льꙃєватєл҄ьска страни́ца',
+'tooltip-pt-mytalk'              => 'твоꙗ́ бєсѣ́дꙑ страни́ца',
+'tooltip-pt-preferences'         => 'твои строи',
+'tooltip-pt-mycontris'           => 'твоꙗ́ добродѣꙗ́ниѩ ката́логъ',
+'tooltip-pt-logout'              => 'ис̾хо́дъ',
+'tooltip-ca-talk'                => 'си страни́цѧ бєсѣ́да',
+'tooltip-ca-viewsource'          => 'си страни́ца ꙁабранєна́ ѥ́стъ ⁙
 ѥѩ исто́чьнъ о́браꙁъ ви́дєти мо́жєщи',
-'tooltip-ca-protect'       => 'си страни́цѧ ꙁабранє́ниѥ',
-'tooltip-ca-delete'        => 'си страни́цѧ поничьжє́ниѥ',
-'tooltip-ca-move'          => 'си страни́цѧ прѣимєнова́ниѥ',
-'tooltip-ca-watch'         => 'си страни́цѧ блюдє́ниѥ',
-'tooltip-p-logo'           => 'гла́вьна страни́ца',
-'tooltip-n-mainpage'       => 'ви́ждь гла́вьнѫ страни́цѫ',
-'tooltip-n-recentchanges'  => 'послѣ́дьнъ мѣ́нъ ката́логъ',
-'tooltip-t-upload'         => 'положє́ниѥ дѣ́лъ',
-'tooltip-t-specialpages'   => 'вьсѣѩ наро́чьнъ страни́цѧ ката́логъ',
-'tooltip-ca-nstab-special' => 'си наро́чьна страни́ца ѥ́стъ · ѥѩжє иꙁмѣнꙗ́ти нє можєши',
-'tooltip-watch'            => 'си страни́цѧ блюдє́ниѥ',
+'tooltip-ca-protect'             => 'си страни́цѧ ꙁабранє́ниѥ',
+'tooltip-ca-delete'              => 'си страни́цѧ поничьжє́ниѥ',
+'tooltip-ca-move'                => 'си страни́цѧ прѣимєнова́ниѥ',
+'tooltip-ca-watch'               => 'си страни́цѧ блюдє́ниѥ',
+'tooltip-search'                 => 'ищи {{{grammar:genitive|{{SITENAME}}}}} страни́цѧ',
+'tooltip-p-logo'                 => 'гла́вьна страни́ца',
+'tooltip-n-mainpage'             => 'ви́ждь гла́вьнѫ страни́цѫ',
+'tooltip-n-mainpage-description' => 'ви́ждь гла́вьнѫ страни́цѫ',
+'tooltip-n-recentchanges'        => 'послѣ́дьн҄ь мѣ́нъ ката́логъ',
+'tooltip-t-upload'               => 'положє́ниѥ дѣ́лъ',
+'tooltip-t-specialpages'         => 'вьсѣѩ наро́чьнъ страни́цѧ ката́логъ',
+'tooltip-t-print'                => 'сѥѩ страни́цѧ пєча́тьнъ о́браꙁъ',
+'tooltip-ca-nstab-special'       => 'си наро́чьна страни́ца ѥ́стъ · ѥѩжє иꙁмѣнꙗ́ти нє можєши',
+'tooltip-watch'                  => 'си страни́цѧ блюдє́ниѥ',
 
 # Media information
 'file-info-size' => '($1 × $2 п҃ѯ · дѣ́ла мѣ́ра : $3 · MIME тѵ́пъ : $4)',
@@ -622,8 +695,8 @@ $messages = array(
 'size-bytes' => '$1 Б҃',
 
 # Special:Version
-'version'                  => 'MediaWiki о́браꙁъ', # Not used as normal message but as header for the special page itself
-'version-version'          => 'о́браꙁъ',
+'version'                  => 'MediaWiki о́браꙁъ',
+'version-version'          => '(о́браꙁъ $1)',
 'version-license'          => 'прощє́ниѥ',
 'version-software-version' => 'о́браꙁъ',
 
