@@ -20,11 +20,9 @@ $linkPrefixExtension = true;
 $namespaceNames = array(
 	NS_MEDIA            => 'Медиа',
 	NS_SPECIAL          => 'Ятарлă',
-	NS_MAIN             => '',
 	NS_TALK             => 'Сӳтсе явасси',
 	NS_USER             => 'Хутшăнакан',
 	NS_USER_TALK        => 'Хутшăнаканăн_канашлу_страници',
-	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK     => '$1_сӳтсе_явмалли',
 	NS_FILE             => 'Ӳкерчĕк',
 	NS_FILE_TALK        => 'Ӳкерчĕке_сӳтсе_явмалли',
@@ -113,18 +111,18 @@ $messages = array(
 'october'       => 'юпа',
 'november'      => 'чӳк',
 'december'      => 'раштав',
-'january-gen'   => 'кăрлач',
-'february-gen'  => 'нарăс',
-'march-gen'     => 'пуш',
-'april-gen'     => 'ака',
-'may-gen'       => 'çу',
-'june-gen'      => 'çĕртме',
-'july-gen'      => 'утă',
-'august-gen'    => 'çурла',
-'september-gen' => 'авăн',
-'october-gen'   => 'юпа',
-'november-gen'  => 'чӳк',
-'december-gen'  => 'раштав',
+'january-gen'   => 'кăрлач уйăхĕн',
+'february-gen'  => 'нарăс уйăхĕн',
+'march-gen'     => 'пуш уйăхĕн',
+'april-gen'     => 'ака уйăхĕн',
+'may-gen'       => 'çу уйăхĕн',
+'june-gen'      => 'çĕртме уйăхĕн',
+'july-gen'      => 'утă уйăхĕн',
+'august-gen'    => 'çурла уйăхĕн',
+'september-gen' => 'авăн уйăхĕн',
+'october-gen'   => 'юпа уйăхĕн',
+'november-gen'  => 'чӳк уйăхĕн',
+'december-gen'  => 'раштав уйăхĕн',
 'jan'           => 'кăр',
 'feb'           => 'нар',
 'mar'           => 'пуш',
@@ -145,7 +143,7 @@ $messages = array(
 'category-media-header'          => '«$1» категорири файлсем',
 'category-empty'                 => "''Хальхи вăхăтра ку категори пушă.''",
 'hidden-categories'              => '{{PLURAL:$1|Пытарнă категори|Пытарнă категорисем}}',
-'hidden-category-category'       => 'Пытарнă категорисем', # Name of the category where hidden categories will be listed
+'hidden-category-category'       => 'Пытарнă категорисем',
 'category-subcat-count'          => '{{PLURAL:$2|Ку категоринче çак айри категори пур.|$2-ран(-рен,-тан,-тен) {{PLURAL:$1|$1 айри категорине кăтартнă|$1 айри категорине кăтартнă|$1 айри категорине кăтартнă}}.}}',
 'category-subcat-count-limited'  => 'Ку категоринче {{PLURAL:$1|$1 айри категори|$1 айри категори|$1 айри категори}}.',
 'category-article-count'         => '{{PLURAL:$2|Ку категоринче пĕр страница кăна.|Ку категорири $2 страницăран $1 кăтартнă.}}',
@@ -163,10 +161,18 @@ $messages = array(
 * [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki тăрăх час-часах ыйтакан ыйтусемпе хуравсем];
 * [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki çĕнĕ верси тухнине пĕлтерекен рассылка].',
 
-'about'          => 'Ăнлантаркăч',
-'article'        => 'Статья',
-'newwindow'      => '(çĕнĕ чӳречере)',
-'cancel'         => 'Пăрахăçла',
+'about'         => 'Ăнлантаркăч',
+'article'       => 'Статья',
+'newwindow'     => '(çĕнĕ чӳречере)',
+'cancel'        => 'Пăрахăçла',
+'moredotdotdot' => 'Малалла…',
+'mypage'        => 'Ман страница',
+'mytalk'        => 'Ман канашлу страници',
+'anontalk'      => 'Çак IP-адреса сӳтсе явни',
+'navigation'    => 'Меню',
+'and'           => '&#32;тата',
+
+# Cologne Blue skin
 'qbfind'         => 'Шырав',
 'qbbrowse'       => 'Курăм',
 'qbedit'         => 'Тӳрлет',
@@ -174,15 +180,28 @@ $messages = array(
 'qbpageinfo'     => 'Страница çинчен',
 'qbmyoptions'    => 'Сирĕн ĕнĕрлевсем',
 'qbspecialpages' => 'Ятарлӑ страницӑсем',
-'moredotdotdot'  => 'Малалла…',
-'mypage'         => 'Ман страница',
-'mytalk'         => 'Ман канашлу страници',
-'anontalk'       => 'Çак IP-адреса сӳтсе явни',
-'navigation'     => 'Меню',
-'and'            => '&#32;тата',
+'faq'            => 'ЫйХу',
+'faqpage'        => 'Project:ЫйХу',
 
-# Metadata in edit box
-'metadata_help' => 'Метаданнăйсем:',
+# Vector skin
+'vector-action-addsection'   => 'Тема хуш',
+'vector-action-delete'       => 'Кăларса пăрах',
+'vector-action-move'         => 'Ятне улăштар',
+'vector-action-protect'      => 'Хӳтĕле',
+'vector-namespace-category'  => 'Категори',
+'vector-namespace-help'      => 'Пулăшу страници',
+'vector-namespace-image'     => 'Файл',
+'vector-namespace-main'      => 'Страница',
+'vector-namespace-mediawiki' => 'Пĕлтерӳ',
+'vector-namespace-project'   => 'Проект çинчен',
+'vector-namespace-special'   => 'Ятарлă страницă',
+'vector-namespace-talk'      => 'Сӳтсе яв',
+'vector-namespace-template'  => 'Шаблон',
+'vector-namespace-user'      => 'Хутшăнакан страници',
+'vector-view-create'         => 'Çĕннине ту',
+'vector-view-edit'           => 'Тӳрлет',
+'vector-view-history'        => 'Кун-çул',
+'vector-view-view'           => 'Вула',
 
 'errorpagetitle'    => 'Йăнăш',
 'returnto'          => '$1 страницăна таврăн.',
@@ -229,10 +248,10 @@ $messages = array(
 'viewhelppage'      => 'Справка страницине пăх',
 'categorypage'      => 'Категори страницине пăх',
 'viewtalkpage'      => 'Сӳтсе явнине тишкер',
-'otherlanguages'    => 'Урăх чěлхесем',
+'otherlanguages'    => 'Урăх чĕлхесем',
 'redirectedfrom'    => '($1 çинчен куçарнă)',
 'redirectpagesub'   => 'Куçаракан страница',
-'lastmodifiedat'    => 'Ку страницăна юлашки улăштарнă вăхăт: $2, $1.', # $1 date, $2 time
+'lastmodifiedat'    => 'Ку страницăна юлашки улăштарнă вăхăт: $2, $1.',
 'viewcount'         => 'Ку страницăна $1 хут пăхнă.',
 'protectedpage'     => 'Хӳтĕленĕ статья',
 'jumpto'            => 'Куçас:',
@@ -243,7 +262,6 @@ $messages = array(
 'aboutsite'            => '{{SITENAME}} çинчен',
 'aboutpage'            => 'Project:çинчен',
 'copyright'            => 'Ку ăшлăх $1 килĕшӳллĕн сарăлать.',
-'copyrightpagename'    => '{{SITENAME}} проектăн автор прависем',
 'copyrightpage'        => '{{ns:project}}:Автор прависем',
 'currentevents'        => 'Хыпарсем',
 'currentevents-url'    => 'Project:Хыпарсем',
@@ -251,10 +269,8 @@ $messages = array(
 'disclaimerpage'       => 'Project:Яваплăха тивĕçтерменни',
 'edithelp'             => 'Улшăнусене кĕртме пулăшакан пулăшу',
 'edithelppage'         => 'Help:Улшăнусене кĕртме пулăшакан пулăшу',
-'faq'                  => 'ЫйХу',
-'faqpage'              => 'Project:ЫйХу',
 'helppage'             => 'Help:Пулăшу',
-'mainpage'             => 'Тĕп страницă',
+'mainpage'             => 'Тĕп страница',
 'mainpage-description' => 'Тĕп страницă',
 'policy-url'           => 'Project:Йĕркесем',
 'portal'               => 'Портал',
@@ -326,10 +342,6 @@ MySQL çак йăнăша тавăрнă <tt>«$3: $4»</tt>.',
 «$1»
 «$2» функци ыйтнă.
 MySQL çак йăнăша тавăрнă «$3: $4».',
-'noconnect'            => 'Каçарăр та, хальхи вăхăтра техника йăнăшне пула пĕлĕм пуххин серверĕпе çыханаймастпăр.<br />
-$1',
-'nodb'                 => '$1 пĕлĕм пуххине усă курма май çук',
-'cachederror'          => 'Аяларах эсир ыйтнă страницăн кэшри копине куратăр; вăл кивелме те пултарнă.',
 'laggedslavemode'      => 'Асăрхăр! Страница çинче юлашки улшăнусене кăтартмасăр пултарнă.',
 'readonly'             => 'Пĕлĕм пуххине çырассине чарса хунă',
 'enterlockreason'      => 'Чарнин сăлтавне тата палăртнă вăхăта кăтартăр.',
@@ -384,7 +396,6 @@ $1',
 'virus-unknownscanner' => 'паллă мар антивирус:',
 
 # Login and logout pages
-'logouttitle'                => 'Сайтран тух',
 'logouttext'                 => 'Эсир палласа илмен хутшăнакан евĕр ĕçлетĕр.
 Сайт сире ятпа мар, IP-адрес урлă пĕлет.
 Эсир анонимла, е малтанхи евĕрлĕ çĕнĕ сеанс уçса, е  урăх ятпа ĕçлеме пултаратăр.
@@ -392,7 +403,6 @@ $1',
 'welcomecreation'            => '== Ырă сунса кĕтетпĕр, $1! ==
 Эсир пирĕн патăмăрта çырăнтăр.
 [[Special:Preferences|Сайт ĕнĕрлевĕсене хăвсамăра кирлĕ пек]] лартма ан манса кайăр.',
-'loginpagetitle'             => 'Сайта кĕр',
 'yourname'                   => 'Сирĕн ят',
 'yourpassword'               => 'Вăрттăн сăмах:',
 'yourpasswordagain'          => 'Вăрттăн сăмах тепре çырăр:',
@@ -413,19 +423,7 @@ $1',
 'createaccountmail'          => 'эл. почта тăрăх',
 'badretype'                  => 'Эсир кăтартнă парольсем пĕр пек мар.',
 'userexists'                 => 'Эсир усă курас теекен ята йышăннă. Тархасшăн, урăх ят суйласа илĕр.',
-'youremail'                  => 'Электронлă почта:',
-'username'                   => 'Хутшăнакан ячĕ:',
-'uid'                        => 'Хутшăнакан идентификаторĕ:',
-'yourrealname'               => 'Сирĕн чăн ят (*)',
-'yourlanguage'               => 'Интерфейс чĕлхи:',
-'yourvariant'                => 'Чĕлхе варианчĕ',
-'yournick'                   => 'Сирĕн ят (алă пусма усă курăнĕ):',
-'badsig'                     => 'Алă пуснинче йăнăш пур. HTML тэгĕсене тĕрĕслĕр.',
-'badsiglength'               => 'Алă пусни ытла вăрăм, $1 символтан кĕскерех пулмалла.',
-'email'                      => 'Эл. почта',
 'loginerror'                 => 'Хутшăнакана палласа илеймерĕмĕр',
-'prefs-help-email'           => 'Электронлă почта (вăл кирлисем шутне кĕмест пулин те) ытти хутшăнакансене сирĕнпе ун урлă çыхăнма май парать. Çыхăну тытнă вăхăтра ыттисем сирĕн адреса пĕлеймеççĕ.',
-'prefs-help-email-required'  => 'Электронлă почтăн адресне кăтартмалла.',
 'noname'                     => 'Эсир килĕшӳллĕ хутшăнаканăн ятне кăтартман.',
 'loginsuccesstitle'          => 'Сайта кĕтĕмĕр',
 'loginsuccess'               => 'Халĕ эсир $1 ятпа ĕçлетĕр.',
@@ -458,32 +456,34 @@ $1',
 'newpassword'             => 'Çěнě пароль',
 'resetpass_submit'        => 'Вăрттăн сăмаха лартса сайта кĕр',
 'resetpass_forbidden'     => 'Вăрттăн сăмаха улăштарма май çук',
+'resetpass-submit-cancel' => 'Пăрахăçла',
 'resetpass-temp-password' => 'Вăхăтлăх вăрттăн сăмах:',
 
 # Edit page toolbar
-'bold_sample'    => 'Çурмахулăм текст',
-'bold_tip'       => 'Çурмахулăм текст',
-'italic_sample'  => 'Тайлăк текст',
-'italic_tip'     => 'Тайлăк текст',
-'link_sample'    => 'Каçăн ячĕ',
-'link_tip'       => 'Шалти каçă',
-'extlink_sample' => 'http://www.example.com каçăн ячĕ',
-'extlink_tip'    => 'Тулаш каçи (http:// префикс çинчен ан манăр)',
-'headline_tip'   => 'Иккĕмĕш шайри ят',
-'math_sample'    => 'Формулăна кунта кĕртĕр',
-'math_tip'       => 'Математика формули (LaTeX форматпа)',
-'nowiki_sample'  => 'Кунта фотматламан текста кĕртĕр.',
-'nowiki_tip'     => 'Вики-ĕрешлевне пăхмалла мар',
-'image_tip'      => 'Кĕртсе лартнă ӳкерчĕк',
-'media_tip'      => 'Медиа-файл çине каçă',
-'sig_tip'        => 'Сирĕн алă пусни тата вăхăт',
-'hr_tip'         => 'Горизонтальлĕ йĕр (сахалтарах усă курăр)',
+'bold_sample'     => 'Çурмахулăм текст',
+'bold_tip'        => 'Çурмахулăм текст',
+'italic_sample'   => 'Тайлăк текст',
+'italic_tip'      => 'Тайлăк текст',
+'link_sample'     => 'Каçăн ячĕ',
+'link_tip'        => 'Шалти каçă',
+'extlink_sample'  => 'http://www.example.com каçăн ячĕ',
+'extlink_tip'     => 'Тулаш каçи (http:// префикс çинчен ан манăр)',
+'headline_sample' => 'Пуçелĕк',
+'headline_tip'    => 'Иккĕмĕш шайри ят',
+'math_sample'     => 'Формулăна кунта кĕртĕр',
+'math_tip'        => 'Математика формули (LaTeX форматпа)',
+'nowiki_sample'   => 'Кунта фотматламан текста кĕртĕр.',
+'nowiki_tip'      => 'Вики-ĕрешлевне пăхмалла мар',
+'image_tip'       => 'Кĕртсе лартнă ӳкерчĕк',
+'media_tip'       => 'Медиа-файл çине каçă',
+'sig_tip'         => 'Сирĕн алă пусни тата вăхăт',
+'hr_tip'          => 'Горизонтальлĕ йĕр (сахалтарах усă курăр)',
 
 # Edit pages
-'summary'                => 'Улшăнусен кĕске ăнлантарăвĕ:',
+'summary'                => 'Улшăнусен ăнлантарăвĕ:',
 'subject'                => 'Тема:',
-'minoredit'              => 'Кунта пěчěк улшăнусем кăна кěртнě',
-'watchthis'              => 'Ку страницăна кěртекен  улшăнусем  хыççăн сăнамалла',
+'minoredit'              => 'Пĕчĕк улшăну',
+'watchthis'              => 'Ку страницăна сăна',
 'savearticle'            => 'Страницăна çырса хур',
 'preview'                => 'Епле курăнĕ',
 'showpreview'            => 'Малтанлăхи курăну',
@@ -525,10 +525,11 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'userjspreview'          => "'''Астăвăр, ку сирĕн javascript-файлăн малтанхи курăмĕ кăна, ăна хальлĕхе çырса хуман!'''",
 'updated'                => '(Çĕнелнĕ)',
 'note'                   => "'''Ăнлантаркăч:'''",
-'previewnote'            => "'''Ку страницăна халлěхе çырса хуман. Эсир ку страницă мěнле пулассине кăна куратăр!'''",
+'previewnote'            => "'''Ку страницăна халлĕхе çырса хуман.'''
+Эсир ку страница мĕнле пулассине кăна куратăр!",
 'previewconflict'        => 'Çӳлти чӳречере эсир халĕ çырса хурсан текст епле курăннине куратăр.',
 'editing'                => '$1 тӳрлетни',
-'editingsection'         => '$1 тӳрлетни (статья разделě)',
+'editingsection'         => '$1 тӳрлетни (статья пайĕ)',
 'editingcomment'         => '$1 тӳрлетни (кӗске анлантарӑвӗ)',
 'editconflict'           => 'Тӳрлетнĕ вăхăтра тавлашу тухрĕ: $1',
 'yourtext'               => 'Сирĕн текст',
@@ -559,17 +560,16 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'viewpagelogs'        => 'Ку страницăн журналĕсене пăхасси',
 'nohistory'           => 'Ку страницăн улшăнусен журналĕ çук.',
 'currentrev'          => 'Хальхи верси',
-'revisionasof'        => '$1 верси',
-'revision-info'       => '$1 версийĕ; $2', # Additionally available: $3: revision id
-'previousrevision'    => '&larr;Малтанхи верси',
-'nextrevision'        => 'Çěнěрех верси→',
+'revisionasof'        => '$1 сăнташ',
+'revision-info'       => '$1 версийĕ; $2',
+'previousrevision'    => '← Малтанхи сăнташ',
+'nextrevision'        => 'Тепĕр сăнташ →',
 'currentrevisionlink' => 'хальхи верси çине куç',
 'cur'                 => 'хальхи',
 'next'                => 'тепěр',
 'last'                => 'малт.',
 'page_first'          => 'пĕрремĕш',
 'page_last'           => 'юлашки',
-'deletedrev'          => '[кăларса пăрахнă]',
 'histfirst'           => 'Пĕрремĕш',
 'histlast'            => 'Юлашки',
 'historysize'         => '$1 байт',
@@ -584,6 +584,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'rev-deleted-user'       => '(автор ятне хуратнă)',
 'rev-deleted-event'      => '(кăларса пăрахнă)',
 'rev-delundel'           => 'кăтарт/пытар',
+'rev-showdeleted'        => 'кăтарт',
 'revdelete-legend'       => 'Чару ларт:',
 'revdelete-hide-text'    => 'Страницăн çак верси текстне пытар',
 'revdelete-hide-comment' => 'Комментарине пытар',
@@ -608,44 +609,56 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'searchresults'      => 'Тупрăмăр',
 'notitlematches'     => 'Статьясен ячĕсем пĕр пек мар',
 'textmatches'        => 'Статьясенчи текст пĕрпеклĕхĕ',
-'prevn'              => 'малтанхи $1',
-'nextn'              => 'малалли $1',
+'prevn'              => 'малтанхи {{PLURAL:$1|$1}}',
+'nextn'              => 'малалли {{PLURAL:$1|$1}}',
 'searchhelp-url'     => 'Help:Пулăшу',
 'search-result-size' => '$1 ({{PLURAL:$2|1 сăмах|$2 сăмах}})',
 'showingresults'     => 'Аяларах эсир <b>#$2</b> пуçласа кăтартнă <b>$1</b> йĕркене куратăр.',
 'powersearch'        => 'Анлă шырав',
 'powersearch-legend' => 'Анлă шырав',
 
+# Quickbar
+'qbsettings' => 'Навигаци хăми',
+
 # Preferences page
-'preferences'        => 'Ĕнерлевсем',
-'mypreferences'      => 'Ман ĕнерлевсем',
-'prefs-edits'        => 'Тӳрлетӳсен шучĕ:',
-'prefsnologin'       => 'Эсир сайта кĕмен',
-'qbsettings'         => 'Навигаци хăми',
-'changepassword'     => 'Пароле улăштар',
-'skin'               => 'Ерешленӳ',
-'skin-preview'       => 'Малтанхи курăну',
-'dateformat'         => 'Дата формачĕ',
-'datedefault'        => 'Палăртман чухнехи',
-'math_syntax_error'  => 'синтаксис йăнăшĕ',
-'prefs-rc'           => 'Юлашки улшăнусен страници',
-'prefs-watchlist'    => 'Сăнав списокĕ',
-'prefs-misc'         => 'Ытти ĕнерлевсем',
-'saveprefs'          => 'Çырса хур',
-'textboxsize'        => 'Тӳрлетни',
-'rows'               => 'Йěркесем',
-'columns'            => 'Юпасем:',
-'searchresultshead'  => 'Шыраса тупрăмăр',
-'recentchangesdays'  => 'Çак кунсен хушшинчи юлашки улшăнусене кăтартмалла:',
-'recentchangescount' => 'Списокра çакăн чухлĕ тӳрлетӳ кăтартмалла:',
-'savedprefs'         => 'Сирĕн ĕнерлевсене сыхласа хăвартăмăр',
-'timezonelegend'     => 'Сехет поясĕ',
-'localtime'          => 'Вырăнти вăхăт',
-'servertime'         => 'Сервер вăхăчě',
-'files'              => 'Файлсем',
+'preferences'               => 'Ĕнерлевсем',
+'mypreferences'             => 'Ман ĕнерлевсем',
+'prefs-edits'               => 'Тӳрлетӳсен шучĕ:',
+'prefsnologin'              => 'Эсир сайта кĕмен',
+'changepassword'            => 'Пароле улăштар',
+'prefs-skin'                => 'Ерешленӳ',
+'skin-preview'              => 'Малтанхи курăну',
+'datedefault'               => 'Палăртман чухнехи',
+'prefs-rc'                  => 'Юлашки улшăнусен страници',
+'prefs-watchlist'           => 'Сăнав списокĕ',
+'prefs-misc'                => 'Ытти ĕнерлевсем',
+'saveprefs'                 => 'Çырса хур',
+'prefs-editing'             => 'Тӳрлетни',
+'rows'                      => 'Йěркесем',
+'columns'                   => 'Юпасем:',
+'searchresultshead'         => 'Шыраса тупрăмăр',
+'recentchangesdays'         => 'Çак кунсен хушшинчи юлашки улшăнусене кăтартмалла:',
+'recentchangescount'        => 'Списокра çакăн чухлĕ тӳрлетӳ кăтартмалла:',
+'savedprefs'                => 'Сирĕн ĕнерлевсене сыхласа хăвартăмăр',
+'timezonelegend'            => 'Сехет поясĕ',
+'localtime'                 => 'Вырăнти вăхăт',
+'servertime'                => 'Сервер вăхăчě',
+'prefs-files'               => 'Файлсем',
+'youremail'                 => 'Электронлă почта:',
+'username'                  => 'Хутшăнакан ячĕ:',
+'uid'                       => 'Хутшăнакан идентификаторĕ:',
+'yourrealname'              => 'Сирĕн чăн ят (*)',
+'yourlanguage'              => 'Интерфейс чĕлхи:',
+'yourvariant'               => 'Чĕлхе варианчĕ',
+'yournick'                  => 'Сирĕн ят (алă пусма усă курăнĕ):',
+'badsig'                    => 'Алă пуснинче йăнăш пур. HTML тэгĕсене тĕрĕслĕр.',
+'badsiglength'              => 'Алă пусни ытла вăрăм, $1 символтан кĕскерех пулмалла.',
+'email'                     => 'Эл. почта',
+'prefs-help-email'          => 'Электронлă почта (вăл кирлисем шутне кĕмест пулин те) ытти хутшăнакансене сирĕнпе ун урлă çыхăнма май парать. Çыхăну тытнă вăхăтра ыттисем сирĕн адреса пĕлеймеççĕ.',
+'prefs-help-email-required' => 'Электронлă почтăн адресне кăтартмалла.',
 
 # User rights
-'userrights'               => 'Хутшăнакансен прависемпе ĕçлесси', # Not used as normal message but as header for the special page itself
+'userrights'               => 'Хутшăнакансен прависемпе ĕçлесси',
 'userrights-lookup-user'   => 'Хутшăнакансен ушкăнĕсемпе ĕçлесси',
 'userrights-user-editname' => 'Хутшăнакан ятне кăтартăр:',
 'editinguser'              => "тӳрлетни '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
@@ -680,29 +693,36 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'rightsnone'    => '(çук)',
 
 # Recent changes
-'recentchanges'        => 'Улшăнусем',
-'recentchanges-legend' => 'Çĕнĕ улшăнусен ĕнерлевĕ',
-'rcnote'               => 'Юлашки <strong>$2</strong> кун хушшинчи <strong>$1</strong> улшăнусем. Халě пěтěмпе  <strong>{{NUMBEROFARTICLES}}</strong> статья.',
-'rclistfrom'           => 'Юлашки улшăнусене $1 вăхăтран пуçласа кăтартнă',
-'rcshowhideminor'      => 'пĕчĕк тӳрлетӳсене $1',
-'rcshowhidebots'       => 'ботсене $1',
-'rcshowhideliu'        => 'сайта кĕнĕскерсене $1',
-'rcshowhideanons'      => 'ячĕсене палăртманскерсене $1',
-'rcshowhidepatr'       => 'тĕрĕсленĕ тӳрлетӳсене $1',
-'rcshowhidemine'       => 'хăвăн тӳрлетӳсене $1',
-'rclinks'              => 'Юлашки $2 кун хушшинче тунă $1 улшăнусене кăтартмалла<br />$3',
-'diff'                 => 'танл.',
-'hist'                 => 'истори',
-'hide'                 => 'кăтартмалла мар',
-'show'                 => 'кăтартмалла',
-'minoreditletter'      => 'п',
-'newpageletter'        => 'Ç',
-'rc_categories_any'    => 'Кашни',
-'newsectionsummary'    => '/* $1 */ Çĕнĕ тема',
+'recentchanges'                    => 'Улшăнусем',
+'recentchanges-legend'             => 'Çĕнĕ улшăнусен ĕнерлевĕ',
+'recentchanges-legend-newpage'     => '$1 — çĕнĕ страница',
+'recentchanges-legend-minor'       => '$1 — пĕчĕк улшăну',
+'recentchanges-legend-bot'         => '$1 — бот улăштарни',
+'recentchanges-label-bot'          => 'Ку улшăнăва бот тунă',
+'recentchanges-legend-unpatrolled' => '$1 — тĕрĕслемен улшăну',
+'rcnote'                           => 'Юлашки <strong>$2</strong> кун хушшинчи <strong>$1</strong> улшăнусем. Халě пěтěмпе  <strong>{{NUMBEROFARTICLES}}</strong> статья.',
+'rclistfrom'                       => 'Юлашки улшăнусене $1 вăхăтран пуçласа кăтартнă',
+'rcshowhideminor'                  => 'пĕчĕк тӳрлетӳсене $1',
+'rcshowhidebots'                   => 'ботсене $1',
+'rcshowhideliu'                    => 'сайта кĕнĕскерсене $1',
+'rcshowhideanons'                  => 'ячĕсене палăртманскерсене $1',
+'rcshowhidepatr'                   => 'тĕрĕсленĕ тӳрлетӳсене $1',
+'rcshowhidemine'                   => 'хăвăн тӳрлетӳсене $1',
+'rclinks'                          => 'Юлашки $2 кун хушшинче тунă $1 улшăнусене кăтартмалла<br />$3',
+'diff'                             => 'танл.',
+'hist'                             => 'истори',
+'hide'                             => 'кăтартмалла мар',
+'show'                             => 'кăтартмалла',
+'minoreditletter'                  => 'п',
+'newpageletter'                    => 'Ç',
+'rc_categories_any'                => 'Кашни',
+'newsectionsummary'                => '/* $1 */ Çĕнĕ тема',
 
 # Recent changes linked
-'recentchangeslinked'      => 'Çыхăннă улшăнусем',
-'recentchangeslinked-page' => 'Страница ячĕ:',
+'recentchangeslinked'         => 'Çыхăннă улшăнусем',
+'recentchangeslinked-feed'    => 'Çыхăннă улшăнусем',
+'recentchangeslinked-toolbox' => 'Çыхăннă улшăнусем',
+'recentchangeslinked-page'    => 'Страница ячĕ:',
 
 # Upload
 'upload'             => 'Файла кĕртесси',
@@ -759,6 +779,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'listfiles_description' => 'Ăнлантаркăч',
 
 # File description page
+'file-anchor-link'          => 'Файл',
 'filehist'                  => 'Файл историйĕ',
 'filehist-current'          => 'хальхи',
 'filehist-user'             => 'Хутшăнакан',
@@ -766,9 +787,6 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'imagelinks'                => 'Файл çине каçасем',
 'linkstoimage'              => 'Çак страницăсем ку файл çине кăтартаççĕ:',
 'nolinkstoimage'            => 'Ку файл çине кăтартакан страницăсем çук.',
-'shareduploadwiki'          => 'Тĕплĕнрех информацине $1 синче тупма пулать.',
-'noimage'                   => 'Ун пек ятлă файл çук, эсир ăна $1.',
-'noimage-linktext'          => 'кĕртме пултаратăр',
 'uploadnewversion-linktext' => 'Ку файлăн çĕнĕ версине кĕрт',
 
 # File reversion
@@ -796,7 +814,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 # Unused templates
 'unusedtemplates'     => 'Усă курман шаблонсем',
 'unusedtemplatestext' => 'Ку страница çинче страницăсенче усă курман «Шаблон» ятлă ятсен уçлăхне шутне кĕрекен страницăсене куратăр.',
-'unusedtemplateswlh'  => 'ытти ссылкăсем',
+'unusedtemplateswlh'  => 'ытти каçăсем',
 
 # Random page
 'randompage' => 'Ăнсăртран илнě страницă',
@@ -805,6 +823,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'randomredirect' => 'Ăнсăртран илнĕ куçару',
 
 # Statistics
+'statistics'              => 'Статистика',
 'statistics-header-users' => 'Хутшăнакансен статистики',
 'statistics-mostpopular'  => 'Чи нумай пăхакан страницăсем',
 
@@ -818,13 +837,14 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 
 'brokenredirects'        => 'Татăк куçару страницисем',
 'brokenredirectstext'    => 'Ку куçару страницисем çук страницăна куçараççĕ:',
-'brokenredirects-edit'   => '(тӳрлет)',
-'brokenredirects-delete' => '(кăларса пăрах)',
+'brokenredirects-edit'   => 'тӳрлет',
+'brokenredirects-delete' => 'кăларса пăрах',
 
 'fewestrevisions' => 'Сахал тӳрлетнĕ статьясем',
 
 # Miscellaneous special pages
 'nbytes'                  => '$1 {{PLURAL:$1|байт|байт}}',
+'nlinks'                  => '$1 {{PLURAL:$1|каçă|каçă}}',
 'nviews'                  => '$1 хут пăхнă',
 'specialpage-empty'       => 'Ку страница пушă',
 'lonelypages'             => 'Тăлăх страницăсем',
@@ -837,7 +857,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'wantedcategories'        => 'Хатĕрлемелли категорисем',
 'wantedpages'             => 'Хатĕрлемелли страницăсем',
 'mostlinked'              => 'Ку страницăсем çине чи нумай ссылка лартнă',
-'mostlinkedcategories'    => 'Ку категорисем чи нумай ссылкăсем лартнă',
+'mostlinkedcategories'    => 'Ку категорисем чи нумай каçă лартнă',
 'mostlinkedtemplates'     => 'Чи анлă усă куракан шаблонсем',
 'mostcategories'          => 'Чи нумай категорине кĕртнĕ страницăсем',
 'mostimages'              => 'Чи анлă усă куракан ӳкерчĕксем',
@@ -849,7 +869,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'protectedpages'          => 'хӳтĕленĕ страницăсем',
 'protectedtitles'         => 'Юраман ятсем',
 'listusers'               => 'Хутшăнакансен списокĕ',
-'newpages'                => 'Çěнě страницăсем',
+'newpages'                => 'Çĕнĕ страницăсем',
 'newpages-username'       => 'Хутшăнакан:',
 'ancientpages'            => 'Чи кивĕ статьясем',
 'move'                    => 'Ятне улăштар',
@@ -882,7 +902,9 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 
 # Special:Categories
 'categories'                    => 'Категорисем',
-'categoriespagetext'            => 'Викинче çак категорисем пур.',
+'categoriespagetext'            => 'Викинче çак категорисем пур.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 'special-categories-sort-count' => 'шучĕ тăрăх йĕркеле',
 'special-categories-sort-abc'   => 'алфавит тăрăх йĕркеле',
 
@@ -987,9 +1009,11 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'contribsub2'   => '$1 ӳсĕмĕ ($2)',
 'uctop'         => ' (пуçламăш)',
 
-'sp-contributions-blocklog' => 'Чарса лартнисен журналĕ',
-'sp-contributions-search'   => 'Тӳпе шыравĕ',
-'sp-contributions-submit'   => 'Шырас',
+'sp-contributions-blocklog'   => 'Чарса лартнисен журналĕ',
+'sp-contributions-talk'       => 'Сӳтсе яв',
+'sp-contributions-userrights' => 'Хутшăнакансен прависемпе ĕçлесси',
+'sp-contributions-search'     => 'Тӳпе шыравĕ',
+'sp-contributions-submit'     => 'Шырас',
 
 # What links here
 'whatlinkshere'         => 'Кунта килекен каçăсем',
@@ -1002,7 +1026,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'blockip'                  => 'Хăтшăнакана ĕçлеме чар',
 'ipbreason'                => 'Сăлтавĕ',
 'ipbother'                 => 'Урăх вăхăт:',
-'ipboptions'               => '2 сехет:2 hours,1 кун:1 day,3 кун:3 days,1 эрне:1 week,2 эрне:2 weeks,1 уйăх:1 month,3 уйăх:3 months,6 уйăх:6 months,1 çул:1 year,яванлăха:infinite', # display1:time1,display2:time2,...
+'ipboptions'               => '2 сехет:2 hours,1 кун:1 day,3 кун:3 days,1 эрне:1 week,2 эрне:2 weeks,1 уйăх:1 month,3 уйăх:3 months,6 уйăх:6 months,1 çул:1 year,яванлăха:infinite',
 'ipbotheroption'           => 'урăххи',
 'badipaddress'             => 'IP-адрес формачĕ тĕрĕс мар, е ку ятлă хутшăнакан кунта çук.',
 'blockipsuccesssub'        => 'Ĕçлеме чартăмăр',
@@ -1030,7 +1054,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'newtitle'                => 'Çĕнĕ ят',
 'move-watch'              => 'Ку страницăна сăнамаллисем шутне хуш',
 'movepagebtn'             => 'Страницăн ятне улăштар',
-'pagemovedsub'            => 'Куçарас ěç тěрěс иртрě',
+'pagemovedsub'            => 'Куçарас ĕç тĕрĕс иртрĕ',
 'articleexists'           => 'Ку ятлă статья е пур, е ун пек ят пама юрамасть.
 Тархасшăн, статьяна урăх ят парăр.',
 'talkexists'              => "'''Страницăн ятне улăштартăмăр, анчах та сӳтсе явмалли страницăн ятне улăштараймарăмар — вăл ятлă страницăна маларах хатĕрленĕ. Тархасшăн, вĕсене хăвăр тĕллĕн çыпăçтарăр.'''",
@@ -1052,10 +1076,9 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'export-templates' => 'Шаблонсене ĕçлеттер',
 
 # Namespace 8 related
-'allmessages'         => 'Система пĕлтерĕвĕсем',
-'allmessagesname'     => 'Пĕлтерӳ',
-'allmessagescurrent'  => 'Хальхи текст',
-'allmessagesmodified' => 'Улăштарнисене кăна кăтартмалла',
+'allmessages'        => 'Система пĕлтерĕвĕсем',
+'allmessagesname'    => 'Пĕлтерӳ',
+'allmessagescurrent' => 'Хальхи текст',
 
 # Thumbnails
 'thumbnail-more'           => 'Пысăклатмалли',
@@ -1097,7 +1120,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 
 # Attribution
 'anonymous'        => '{{GRAMMAR:genitive|{{SITENAME}}}} анонимлă хутшăнакансем',
-'lastmodifiedatby' => 'Ку страницăна юлашки хут $2, $1 вăхăтра $3 хутшăнакан улăштарнă.', # $1 date, $2 time, $3 user
+'lastmodifiedatby' => 'Ку страницăна юлашки хут $2, $1 вăхăтра $3 хутшăнакан улăштарнă.',
 'othercontribs'    => '$1 ĕçĕ çинче никĕсленнĕ.',
 'others'           => 'ыттисем',
 'creditspage'      => 'Пархатарлăх',
@@ -1118,6 +1141,9 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'mw_math_html'   => 'май пулсан HTML, май çук пулсан — PNG',
 'mw_math_modern' => 'Хальхи браузерсемпе усă курмашкăн сĕннĕ пек',
 
+# Math errors
+'math_syntax_error' => 'синтаксис йăнăшĕ',
+
 # Patrolling
 'markaspatrolleddiff'   => 'Тĕрĕсленĕ тесе палăрт',
 'markaspatrolledtext'   => 'Ку статьяна тĕрĕсленĕ тесе палăртмалла',
@@ -1152,7 +1178,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 
 'exif-scenecapturetype-0' => 'Стандартлă',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-k' => 'км/сех',
 
 # External editor support
@@ -1211,7 +1237,7 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'watchlisttools-view' => 'Ку тӳрлетӳпе çыхăннăскерсем',
 
 # Special:Version
-'version' => 'MediaWiki версийĕ', # Not used as normal message but as header for the special page itself
+'version' => 'MediaWiki версийĕ',
 
 # Special:FilePath
 'filepath'        => 'Файл çулĕ',
