@@ -33,30 +33,39 @@ $namespaceNames = array(
 
 $messages = array(
 # User preference toggles
-'tog-underline'           => 'Cur linnaghyn fo chianglaghyn:',
-'tog-highlightbroken'     => 'Croo kianglaghyn brisht <a href="" class="new">myr shoh</a> (aght elley: myr shoh<a href="" class="internal">?</a>).',
-'tog-hideminor'           => "Follaghey myn-arraghyn ayns caghlaaghyn s'noa",
-'tog-numberheadings'      => 'Cur earrooyn gyn smooinaght er kione-linnaghyn',
-'tog-showtoolbar'         => 'Taishbyney barr greieyn (ta feme ec er JavaScript)',
-'tog-editondblclick'      => 'Reaghey duillagyn lesh crig dooblit (ta feme ec er JavaScript)',
-'tog-rememberpassword'    => "Cooinnee m'ockle arrey er y cho-earrooder shoh",
-'tog-watchcreations'      => 'Cur duillagyn ta crooit aym lesh my rolley arrey',
-'tog-watchdefault'        => 'Cur duillagyn ta reaghit aym lesh my rolley arrey',
-'tog-watchmoves'          => 'Cur duillagyn ta scughit aym lesh my rolley arrey',
-'tog-watchdeletion'       => 'Cur duillagyn ta scryssit aym lesh my rolley arrey',
-'tog-minordefault'        => 'Myr roie-hoieaghey, cowraghey dagh reaghey myr myn-reaghey',
-'tog-previewontop'        => 'Taishbyney roie-haishbynys roish y chishtey reaghey',
-'tog-previewonfirst'      => 'Taishbyney roie-haishbynys ec y chied reaghey',
-'tog-enotifusertalkpages' => 'Cur post-l dou my vees y duillag ymmydeyr aym caghlaa',
-'tog-enotifminoredits'    => 'Cur dou post-l er myn-arraghey duillagyn chammah',
-'tog-shownumberswatching' => 'Taishbyney quoid dy ymmydeyryn ta freill arrey er',
-'tog-fancysig'            => 'Gra dy vel y screeuys myr wikiteks (gyn kiangley seyr-obbragh)',
-'tog-showhiddencats'      => 'Taishbyney ronnaghyn follit',
+'tog-underline'             => 'Cur linnaghyn fo chianglaghyn:',
+'tog-highlightbroken'       => 'Croo kianglaghyn brisht <a href="" class="new">myr shoh</a> (aght elley: myr shoh<a href="" class="internal">?</a>).',
+'tog-justify'               => 'Cur meeryn ayns un linney',
+'tog-hideminor'             => "Follaghey myn-arraghyn ayns caghlaaghyn s'noa",
+'tog-hidepatrolled'         => "Follaghey arraghyn er nyn scrutaghey ayns caghlaaghyn s'noa",
+'tog-newpageshidepatrolled' => "Follaghey duillagyn er nyn scrutaghey 'sy rolley duillagyn noa",
+'tog-numberheadings'        => 'Cur earrooyn gyn smooinaght er kione-linnaghyn',
+'tog-showtoolbar'           => 'Taishbyney barr greieyn (ta feme ec er JavaScript)',
+'tog-editondblclick'        => 'Reaghey duillagyn lesh crig dooblit (ta feme ec er JavaScript)',
+'tog-rememberpassword'      => "Cooinnee m'ockle arrey er y cho-earrooder shoh",
+'tog-watchcreations'        => 'Cur duillagyn ta crooit aym lesh my rolley arrey',
+'tog-watchdefault'          => 'Cur duillagyn ta reaghit aym lesh my rolley arrey',
+'tog-watchmoves'            => 'Cur duillagyn ta scughit aym lesh my rolley arrey',
+'tog-watchdeletion'         => 'Cur duillagyn ta scryssit aym lesh my rolley arrey',
+'tog-minordefault'          => 'Myr roie-hoieaghey, cowraghey dagh reaghey myr myn-reaghey',
+'tog-previewontop'          => 'Taishbyney roie-haishbynys roish y chishtey reaghey',
+'tog-previewonfirst'        => 'Taishbyney roie-haishbynys ec y chied reaghey',
+'tog-enotifusertalkpages'   => 'Cur post-l dou my vees y duillag ymmydeyr aym caghlaa',
+'tog-enotifminoredits'      => 'Cur dou post-l er myn-arraghey duillagyn chammah',
+'tog-shownumberswatching'   => 'Taishbyney quoid dy ymmydeyryn ta freill arrey er',
+'tog-oldsig'                => "Roie-haishbynys jeh'n screeuys t'ayn hannah:",
+'tog-fancysig'              => 'Gra dy vel y screeuys myr wikiteks (gyn kiangley seyr-obbragh)',
+'tog-showhiddencats'        => 'Taishbyney ronnaghyn follit',
 
 'underline-always'  => 'Rieau',
 'underline-never'   => 'Dy bragh',
 'underline-default' => 'Rere roie-hoiaghey y yeeagheyder',
 
+# Font style option in Special:Preferences
+'editfont-default'   => 'Rere roie-hoiaghey y yeeagheyder',
+'editfont-sansserif' => 'Clou gyn trasnane',
+'editfont-serif'     => 'Clou lesh trasnane',
+
 # Dates
 'sunday'        => 'Jedoonee',
 'monday'        => 'Jelune',
@@ -116,7 +125,7 @@ $messages = array(
 'category-media-header'          => 'Meanyn \'sy ronney "$1"',
 'category-empty'                 => "''Cha nel duillagyn ny meanyn ayns y ronney shoh ec y traa t'ayn.''",
 'hidden-categories'              => '{{PLURAL:$1|Ronney follit|Ronnaghyn follit}}',
-'hidden-category-category'       => 'Ronnaghyn follit', # Name of the category where hidden categories will be listed
+'hidden-category-category'       => 'Ronnaghyn follit',
 'category-subcat-count'          => "{{PLURAL:$2|Ta{{PLURAL:$1|&nbsp;ny $1 fo-ronney|'n $1 'o-ronney|'n $1 'o-ronney|&nbsp;ny $1 fo-ronnaghyn}} shoh ec y ronney shoh, jeh'n lane-sym $2.}}",
 'category-subcat-count-limited'  => "{{PLURAL:$1|Ta{{PLURAL:$1|&nbsp;ny $1 fo-ronney|'n $1 'o-ronney|'n $1 'o-ronney|&nbsp;ny $1 fo-ronnaghyn}} shoh ec y ronney shoh.}}",
 'category-article-count'         => "Ta{{PLURAL:$1|'n $1 duillag|'n $1 duillag|'n $1 ghuillag| ny $1 duillagyn}} heese 'sy ronney shoh, jeh'n lame-sym $2.",
@@ -126,10 +135,18 @@ $messages = array(
 
 'mainpagetext' => "'''Ta MediaWiki currit stiagh nish.'''",
 
-'about'          => 'Mychione',
-'article'        => 'Duillag chummal',
-'newwindow'      => '(foshlit ayns uinnag elley eh)',
-'cancel'         => 'Dolley magh',
+'about'         => 'Mychione',
+'article'       => 'Duillag chummal',
+'newwindow'     => '(foshlit ayns uinnag elley eh)',
+'cancel'        => 'Dolley magh',
+'moredotdotdot' => 'Tooilley...',
+'mypage'        => 'My ghuillag',
+'mytalk'        => 'My resoonaght',
+'anontalk'      => "Cur loayrtys da'n IP shoh",
+'navigation'    => 'Stiureydys',
+'and'           => '&#32;as',
+
+# Cologne Blue skin
 'qbfind'         => 'Fow',
 'qbbrowse'       => 'Ronsaghey',
 'qbedit'         => 'Reaghey',
@@ -137,15 +154,32 @@ $messages = array(
 'qbpageinfo'     => 'Co-hecks',
 'qbmyoptions'    => 'My ghuillagyn',
 'qbspecialpages' => 'Duillagyn er lheh',
-'moredotdotdot'  => 'Tooilley...',
-'mypage'         => 'My ghuillag',
-'mytalk'         => 'My resoonaght',
-'anontalk'       => "Cur loayrtys da'n IP shoh",
-'navigation'     => 'Stiureydys',
-'and'            => '&#32;as',
+'faq'            => 'FC',
+'faqpage'        => 'Project:FC',
 
-# Metadata in edit box
-'metadata_help' => 'Metadata:',
+# Vector skin
+'vector-action-addsection'   => 'Cooish noa',
+'vector-action-delete'       => 'Scryss',
+'vector-action-move'         => 'Scughey',
+'vector-action-protect'      => 'Coadee',
+'vector-action-undelete'     => 'Jee-scryss',
+'vector-action-unprotect'    => 'Jee-choadee',
+'vector-namespace-category'  => 'Ronney',
+'vector-namespace-help'      => 'Duillag choonee',
+'vector-namespace-image'     => 'Coadan',
+'vector-namespace-main'      => 'Duillag',
+'vector-namespace-mediawiki' => 'Çhaghteraght',
+'vector-namespace-project'   => 'Duillag shalee',
+'vector-namespace-special'   => 'Duillag er lheh',
+'vector-namespace-talk'      => 'Resoonaght',
+'vector-namespace-template'  => 'Clowan',
+'vector-namespace-user'      => 'Duillag ymmydeyr',
+'vector-view-create'         => 'Croo',
+'vector-view-edit'           => 'Reaghey',
+'vector-view-history'        => 'Jeeagh er shennaghys',
+'vector-view-view'           => 'Lhaih',
+'vector-view-viewsource'     => 'Jeeagh er bun',
+'namespaces'                 => 'Reamyssyn',
 
 'errorpagetitle'    => 'Marranys',
 'returnto'          => 'Goll er ash gys $1.',
@@ -194,7 +228,7 @@ $messages = array(
 'otherlanguages'    => 'Ayns çhengaghyn elley',
 'redirectedfrom'    => '(Aa-enmyssit ass $1)',
 'redirectpagesub'   => 'Duillag aa-enmys',
-'lastmodifiedat'    => "Va'n duillag shoh ceaghlit er $1, ec $2.", # $1 date, $2 time
+'lastmodifiedat'    => "Va'n duillag shoh ceaghlit er $1, ec $2.",
 'protectedpage'     => 'Duillag choadit',
 'jumpto'            => 'Gow gys:',
 'jumptonavigation'  => 'stiureydys',
@@ -204,7 +238,6 @@ $messages = array(
 'aboutsite'            => 'Mychione {{SITENAME}}',
 'aboutpage'            => 'Project:Mychione',
 'copyright'            => 'Ta stoo ry-gheddyn rere $1.',
-'copyrightpagename'    => 'Coip-chiart {{GRAMMAR:genitive|{{SITENAME}}}}',
 'copyrightpage'        => '{{ns:project}}:Coip-chiartyn',
 'currentevents'        => 'Cooishyn y laa',
 'currentevents-url'    => 'Project:Cooishyn y laa',
@@ -212,8 +245,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:Obbalys cadjin',
 'edithelp'             => 'Cooney y reaghey',
 'edithelppage'         => 'Help:Reaghey',
-'faq'                  => 'FC',
-'faqpage'              => 'Project:FC',
 'helppage'             => 'Help:Cummal',
 'mainpage'             => 'Ard-ghuillag',
 'mainpage-description' => 'Ard-ghuillag',
@@ -286,11 +317,9 @@ Cur coontey jeh da [[Special:ListUsers/sysop|reireyder]], as gow notey jeh\'n UR
 'ns-specialprotected'  => 'Cha nod oo reaghey duillagyn er lheh.',
 
 # Login and logout pages
-'logouttitle'                => 'Log magh yn ymmydeyr',
 'welcomecreation'            => '== Failt ort, $1! ==
 Ta dty choontys chrooit nish.<br />
 Ny jean jarrood dty [[Special:Preferences|{{SITENAME}} hosheeaghtyn]] y arraghey.',
-'loginpagetitle'             => 'Log stiagh yn ymmydeyr',
 'yourname'                   => "Dt'ennym ymmydeyr",
 'yourpassword'               => 'Fockle yn arrey:',
 'yourpasswordagain'          => "Aascreeu d'ockle arrey:",
@@ -299,6 +328,7 @@ Ny jean jarrood dty [[Special:Preferences|{{SITENAME}} hosheeaghtyn]] y arraghey
 'nav-login-createaccount'    => 'Log stiagh / croo coontys',
 'loginprompt'                => 'Shegin dhyt cur pooar da minniagyn dy loggal stiagh ayns {{SITENAME}}.',
 'userlogin'                  => 'Log stiagh / croo coontys',
+'userloginnocreate'          => 'Log stiagh',
 'logout'                     => 'Log magh',
 'userlogout'                 => 'Log magh',
 'notloggedin'                => 'Cha nel ou loggit stiagh',
@@ -308,20 +338,8 @@ Ny jean jarrood dty [[Special:Preferences|{{SITENAME}} hosheeaghtyn]] y arraghey
 'gotaccount'                 => "Vel coontys ayd hannah? '''$1'''.",
 'gotaccountlink'             => 'Log stiagh',
 'createaccountmail'          => 'er post-L',
-'youremail'                  => 'Post-L:',
-'username'                   => "Dt'ennym ymmydeyr:",
-'uid'                        => 'Enney ymmydeyr:',
-'yourrealname'               => 'Feer-ennym:',
-'yourlanguage'               => 'Çhengey:',
-'yournick'                   => 'Far-ennym:',
-'yourgender'                 => 'Keintys:',
-'gender-unknown'             => 'Neuhoilshit',
-'gender-male'                => 'Firrinagh',
-'gender-female'              => 'Bwoirrinagh',
-'email'                      => 'Post-L',
-'prefs-help-realname'        => "Ta dt'eer ennym reihyssagh.<br />
-My bailliu eh y chiarail, bee eh ymmydit son cur gys lieh y chur dhyt er son yn obbyr ayd.",
 'loginerror'                 => 'Marranys log stiagh',
+'createaccounterror'         => 'Cha dod shin croo coontys: $1',
 'loginsuccesstitle'          => "T'ou loggalt stiagh",
 'loginsuccess'               => "'''T'ou loggit stiagh ayns {{SITENAME}} myr \"\$1\".'''",
 'nosuchuser'                 => 'Cha nel ymmydeyr lesh yn ennym "$1".<br />
@@ -409,8 +427,8 @@ She $3 dt'enmys IP roie, as she dt'enney ghlass na #$5. Cur ad lesh dagh ooilley
 
 Foddee oo ceaghley yn fockle arrey noa da'n choontys noa shoh er duillag ''[[Special:ChangePassword|cheaghley fockle yn arrey]]'' lurg loggal stiagh.",
 'newarticle'                       => '(Noa)',
-'newarticletext'                   => 'T’ou er jeet trooid kiangley dys duillag nagh vel ayn foast.  
-Son dy chroo y duillag, gow toshiaght screeuyn ‘sy chishtey çheu heese jeh shoh (jeeagh er [[{{MediaWiki:Helppage}}|duillag y chooney]] son ny smoo fys).  
+'newarticletext'                   => 'T’ou er jeet trooid kiangley dys duillag nagh vel ayn foast.
+Son dy chroo y duillag, gow toshiaght screeuyn ‘sy chishtey çheu heese jeh shoh (jeeagh er [[{{MediaWiki:Helppage}}|duillag y chooney]] son ny smoo fys).
 My haink oo dys shoh trooid marranys, crig er cramman ‘erash’ yn jeeagheyder ayd.',
 'noarticletext'                    => "Cha nel teks 'sy duillag shoh ec y traa t'ayn.
 Foddee oo [[Special:Search/{{PAGENAME}}|ronsaghey enmys ny duillag shoh]] ayns duillagyn elley,
@@ -429,8 +447,8 @@ cha nel dty chaghlaaghyn sauailt foast!'''",
 <br />
 Chammah as shen, t’ou gialdyn dooin dy screeu oo hene eh, ny ren oo coip jeh ny ta fo çhiarnys y theay, ny ry-gheddyn dy seyr.
 '''NY CHUR ROISH GYN KIED OBBYR TA FO COIP-CHIART! '''",
-'templatesused'                    => 'Clowanyn ymmydit er y duillag shoh:',
-'templatesusedpreview'             => "Clowanyn ymmydit 'sy roie-haishbynys shoh:",
+'templatesused'                    => '{{PLURAL:$1|Clowan|Chlowan|Chlowan|Clowanyn}} ymmydit er y duillag shoh:',
+'templatesusedpreview'             => "{{PLURAL:$1|Clowan|Chlowan|Chlowan|Clowanyn}} ymmydit 'sy roie-haishbynys shoh:",
 'template-protected'               => '(glast)',
 'template-semiprotected'           => '(lieh-ghlast)',
 'hiddencategories'                 => "Ta'n duillag shoh ayns {{PLURAL:$1|ronney follit|ronney follit|ronney follit|ronnaghyn follit}}",
@@ -439,7 +457,7 @@ Chammah as shen, t’ou gialdyn dooin dy screeu oo hene eh, ny ren oo coip jeh n
 Foddee shiu goll er ash as reaghey duillag t'ayn nish, ny [[Special:UserLogin|loggal stiagh ny croo coontys]].",
 'nocreate-loggedin'                => 'Cha nel kied ayd duillagyn noa y chroo er {{SITENAME}}.',
 'permissionserrorstext-withaction' => 'Cha nel kiart ayd y $2, er {{PLURAL:$1|y fa|y fa}}:',
-'recreate-deleted-warn'            => "'''Raaue: Ta shiu aachroo duillag as eh er ve scrysst roie.'''
+'recreate-moveddeleted-warn'       => "'''Raaue: Ta shiu aachroo duillag as eh er ve scrysst roie.'''
 
 By chair dhyt smooinagh vel eh kiart goll er oai lesh reaghey yn duillag shoh.<br />
 Ta lioar ny scryssaghyn magh kiarit ayns shoh rere dty chaays hene:",
@@ -450,8 +468,9 @@ Ta lioar ny scryssaghyn magh kiarit ayns shoh rere dty chaays hene:",
 # History pages
 'viewpagelogs'           => 'Jeeagh er lioaryn cooishyn ny duillag shoh',
 'currentrev'             => 'Aavriwnys roie',
+'currentrev-asof'        => 'Aavriwnys roie er $1',
 'revisionasof'           => 'Aavriwnys veih $1',
-'revision-info'          => 'Aavriwnys veih $1 ec $2', # Additionally available: $3: revision id
+'revision-info'          => 'Aavriwnys veih $1 ec $2',
 'previousrevision'       => '←Aavriwnys ny shinney',
 'nextrevision'           => 'Aavriwnys ny saa→',
 'currentrevisionlink'    => 'Aavriwnys roie',
@@ -464,7 +483,6 @@ Ta lioar ny scryssaghyn magh kiarit ayns shoh rere dty chaays hene:",
 Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 '''({{int:last}})''' = anchaslyssyn rish y lhieggan roish, '''{{int:minoreditletter}}''' = mynchaghlaa",
 'history-fieldset-title' => 'Femblal shennaghys',
-'deletedrev'             => '[scryssit]',
 'histfirst'              => 'By hoshee',
 'histlast'               => 'By yerree',
 'historyempty'           => '(follym)',
@@ -472,13 +490,14 @@ Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 # Revision feed
 'history-feed-title'          => 'Shennaghys yn aavriwnys',
 'history-feed-description'    => 'Shennaghys aavriwnys y duillag shoh er yn wiki',
-'history-feed-item-nocomment' => '$1 ec $2', # user at time
+'history-feed-item-nocomment' => '$1 ec $2',
 
 # Revision deletion
 'rev-deleted-comment'  => '(cohaggloo scughit)',
 'rev-deleted-user'     => '(ennym yn ymmydeyr scughit)',
 'rev-delundel'         => 'taishbyney/follaghey',
 'revdelete-hide-image' => 'Cummal y choadan y ollaghey',
+'revdelete-log'        => 'Fa:',
 'revdel-restore'       => 'ceaghley leayrid',
 'pagehist'             => 'Shennaghys y duillag',
 'deletedhist'          => 'Shennaghys scryssit',
@@ -493,6 +512,7 @@ Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 'mergehistory-submit'      => 'Aavriwnyssyn y chochiangley',
 'mergehistory-autocomment' => 'Ta [[:$1]] cochianglit stiagh ayns [[:$2]]',
 'mergehistory-comment'     => 'Ta [[:$1]] cochianglit stiagh ayns [[:$2]]: $3',
+'mergehistory-reason'      => 'Fa:',
 
 # Merge log
 'revertmerge' => 'Jee-vestey',
@@ -510,15 +530,13 @@ Ogher: '''({{int:cur}})''' = anchaslyssyn rish y lhieggan t'ayn nish,
 'searchresulttext'          => 'Son ny smoo oayllys mychione ronsaghtyn er {{SITENAME}}, jeeagh er [[{{MediaWiki:Helppage}}|{{int:help}}]].',
 'searchsubtitle'            => 'Ren oo ronsaght er \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|dagh duillag ta toshiaghey lesh "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|dagh duillag ta kianglt lesh "$1"]])',
 'searchsubtitleinvalid'     => "Ren oo ronsaght er '''$1'''",
-'noexactmatch'              => "'''Cha nel duillag lesh yn ennym \"\$1\".'''
-Foddee oo [[:\$1|croo yn duillag shoh]].",
-'noexactmatch-nocreate'     => "'''Cha nel duillag ayn lesh yn enmys \"\$1\".'''",
 'notitlematches'            => 'Cha nel shen ennym ghuillag erbee',
 'notextmatches'             => 'Cha nel shen ry-lhaih er duillag erbee',
-'prevn'                     => '$1 roish shoh',
-'nextn'                     => 'nah $1',
-'viewprevnext'              => 'Jeeagh er ($1) ($2) ($3)',
+'prevn'                     => '{{PLURAL:$1|$1}} roish shoh',
+'nextn'                     => 'nah {{PLURAL:$1|$1}}',
+'viewprevnext'              => 'Jeeagh er ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url'            => 'Help:Cummal',
+'searchprofile-project'     => 'Duillagyn Coonee as Shalee',
 'search-result-size'        => "$1 ({{PLURAL:$2|1 fockle|$2 'ockle|$2 'ockle|$2 focklyn}})",
 'search-result-score'       => 'Bentynys: $1%',
 'search-redirect'           => '(aa-enmyssit ass $1)',
@@ -533,7 +551,6 @@ Foddee oo [[:\$1|croo yn duillag shoh]].",
 'mwsuggest-disable'         => 'Lhiettal coyrle AJAX',
 'searchrelated'             => 'bentyn rish',
 'searchall'                 => 'yn clane',
-'showingresultstotal'       => "Ny ta heese, shen {{PLURAL:$4|eiyrtys '''$1''' jeh '''$3'''|eiyrtyssyn '''$1 - $2''' jeh '''$3'''}}",
 'nonefound'                 => "'''Notey''':Cha nel eh ronsaghey dagh reamys gyn reih.
 My t'ou uss son ronsaghey dagh cooid (as shen goaill stiagh duillagyn resooney, clowanyn, a.r.e.), cur ''all:'' ec y toshiaght, ny ennym y reamys reih ayd myr roie-ockle (m.s., ''Clowan:'').",
 'powersearch'               => 'Ard-ronsaghey',
@@ -543,23 +560,26 @@ My t'ou uss son ronsaghey dagh cooid (as shen goaill stiagh duillagyn resooney,
 'powersearch-field'         => 'Ronsaghey er son',
 'search-external'           => 'Ronsaghey mooie',
 
+# Quickbar
+'qbsettings-none' => 'Veg',
+
 # Preferences page
 'preferences'               => 'Tosheeaghtyn',
 'mypreferences'             => 'My hosheeaghtyn',
+'prefs-edits'               => 'Earroo caghlaaghyn:',
 'prefsnologin'              => 'Cha nel oo loggit stiagh',
-'qbsettings-none'           => 'Veg',
 'changepassword'            => 'Fockle yn arrey y cheaghley',
-'skin'                      => 'Crackan',
+'prefs-skin'                => 'Crackan',
 'skin-preview'              => 'Roie-haishbynys',
-'dateformat'                => 'Kiaddey yn date',
-'datetime'                  => 'Date as am',
-'math_syntax_error'         => 'Co-ordrail marranagh',
+'prefs-datetime'            => 'Date as am',
 'prefs-personal'            => 'Gruaie yn ymmydeyr',
 'prefs-rc'                  => "Caghlaaghyn s'noa",
 'prefs-watchlist'           => 'Rolley arrey',
 'prefs-watchlist-days'      => 'Laaghyn y haishbyney ayns rolley arrey:',
+'prefs-misc'                => 'Elley',
+'prefs-rendering'           => 'Cummey',
 'saveprefs'                 => 'Sauail',
-'textboxsize'               => 'Reaghey',
+'prefs-editing'             => 'Reaghey',
 'columns'                   => 'Collooyn:',
 'searchresultshead'         => 'Ronsaghey',
 'recentchangesdays'         => "Laaghyn y haishbyney ayns caghlaaghyn s'noa:",
@@ -577,11 +597,27 @@ My t'ou uss son ronsaghey dagh cooid (as shen goaill stiagh duillagyn resooney,
 'timezoneregion-europe'     => 'Yn Oarpey',
 'timezoneregion-indian'     => 'Y Keayn Injinagh',
 'timezoneregion-pacific'    => 'Y Keayn Sheealtagh',
-'default'                   => 'loght',
-'files'                     => 'Coadanyn',
+'prefs-searchoptions'       => 'Ronsaghey',
+'default'                   => 'roie-chiartagh',
+'prefs-files'               => 'Coadanyn',
+'youremail'                 => 'Post-L:',
+'username'                  => "Dt'ennym ymmydeyr:",
+'uid'                       => 'Enney ymmydeyr:',
+'prefs-memberingroups'      => 'Oltey {{PLURAL:$1|possan|phossan|phossan|possanyn}} heese:',
+'prefs-registration'        => 'Traa listal',
+'yourrealname'              => 'Feer-ennym:',
+'yourlanguage'              => 'Çhengey:',
+'yournick'                  => 'Far-ennym:',
+'yourgender'                => 'Keintys:',
+'gender-unknown'            => 'Neuhoilshit',
+'gender-male'               => 'Firrinagh',
+'gender-female'             => 'Bwoirrinagh',
+'email'                     => 'Post-L',
+'prefs-help-realname'       => "Ta dt'eer ennym reihyssagh.<br />
+My bailliu eh y chiarail, bee eh ymmydit son cur gys lieh y chur dhyt er son yn obbyr ayd.",
 
 # User rights
-'userrights'               => 'Reireydys kiartyn ymmydeyr', # Not used as normal message but as header for the special page itself
+'userrights'               => 'Reireydys kiartyn ymmydeyr',
 'userrights-lookup-user'   => 'Possanyn ymmydeyr y stiurey',
 'userrights-user-editname' => 'Screeu stiagh ennym ymmydeyr:',
 'editusergroup'            => 'Possanyn ymmydeyr y reaghey',
@@ -644,6 +680,8 @@ My t'ou uss son ronsaghey dagh cooid (as shen goaill stiagh duillagyn resooney,
 
 # Recent changes linked
 'recentchangeslinked'          => 'Caghlaaghyn-vooinjerys',
+'recentchangeslinked-feed'     => 'Caghlaaghyn-vooinjerys',
+'recentchangeslinked-toolbox'  => 'Caghlaaghyn-vooinjerys',
 'recentchangeslinked-title'    => 'Caghlaaghyn bentyn rish "$1"',
 'recentchangeslinked-noresult' => 'Cha nel caghlaa erbee er duillagyn kianglt car y traa taishbynit.',
 'recentchangeslinked-summary'  => "Shoh rolley caghlaaghyn va jeant er duillagyn kianglt veih duillag sonrit (ny er olteynyn ronney sonrit).<br />
@@ -654,7 +692,6 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 # Upload
 'upload'            => 'Laadey neese coadan',
 'uploadbtn'         => 'Laadey neese coadan',
-'reupload'          => 'Aalaadey neese',
 'uploadnologin'     => 'Cha nel oo loggit stiagh',
 'uploadlogpage'     => 'Lioar laadyn neese',
 'filename'          => 'Ennym y choadan',
@@ -664,7 +701,6 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'filesource'        => 'Bun:',
 'uploadedfiles'     => 'Coadanyn ta laadit neese',
 'badfilename'       => 'T\'ennym y choadan aa-enmyssit myr "$1".',
-'fileexists-thumb'  => "<center>'''Coadan roie'''</center>",
 'savefile'          => 'Sauail y coadan',
 'uploadedimage'     => '"[[$1]]" laadit neese',
 'uploadvirus'       => "Ta veerys 'sy choadan! Mynphoyntyn: $1",
@@ -673,6 +709,7 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'upload-file-error' => 'Marranys ynveanagh',
 
 'license'            => 'Kieddagh:',
+'license-header'     => 'Kieddagh:',
 'license-nopreview'  => '(Cha nel roie-haishbynys ry-gheddyn)',
 'upload_source_file' => ' (coadan er dty cho-earrooder)',
 
@@ -686,6 +723,7 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'listfiles_description' => 'Coontey',
 
 # File description page
+'file-anchor-link'          => 'Coadan',
 'filehist'                  => 'Shennaghys y choadan',
 'filehist-help'             => 'Crig er date/traa ennagh son dy ‘akin y coadan myr v’eh ec y traa shen.',
 'filehist-deleteall'        => 'scryss ooilley',
@@ -694,6 +732,7 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'filehist-current'          => 'bio',
 'filehist-datetime'         => 'Date/Am',
 'filehist-thumb'            => 'Ingin-ordaag',
+'filehist-thumbtext'        => "Ingin-ordaag da'n lhieggan shoh ec $1",
 'filehist-user'             => 'Ymmydeyr',
 'filehist-dimensions'       => 'Mooadyssyn',
 'filehist-filesize'         => 'Mooadys y choadan',
@@ -701,14 +740,11 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'imagelinks'                => 'Kianglaghyn y choadan',
 'linkstoimage'              => 'Ta {{PLURAL:$1|ny $1 duillag|yn $1 duillag|ny $1 ghuillag|ny $1 duillagyn}} eiyrtyssagh kianglt lesh y coadan shoh:',
 'nolinkstoimage'            => 'Cha nel duillag erbee kianglt lesh y coadan shoh.',
-'sharedupload'              => "Ta'n coadan shoh çheet ass $1, as foddee dy beagh eh ymmydit ayns shaleeyn elley.", # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'shareduploadwiki-linktext' => 'duillag huarastyl y choadan',
-'noimage'                   => 'Cha nel coadan erbee ayn as yn ennym shoh er, agh foddee oo $1',
-'noimage-linktext'          => 'laad neese eh',
+'sharedupload'              => "Ta'n coadan shoh çheet ass $1, as foddee dy beagh eh ymmydit ayns shaleeyn elley.",
 'uploadnewversion-linktext' => "Laad neese lhieggan noa jeh'n choadan shoh",
 
 # File reversion
-'filerevert-comment' => 'Cohaggloo:',
+'filerevert-comment' => 'Fa:',
 
 # File deletion
 'filedelete'                  => 'Scryss $1',
@@ -752,8 +788,8 @@ Ta duillagyn er [[Special:Watchlist|dty rolley arrey]] ayns '''clou trome'''.",
 'doubleredirects' => 'Aa-enmyssyn dooblagh',
 
 'brokenredirects'        => 'Aa-enmyssyn brisht',
-'brokenredirects-edit'   => '(reaghey)',
-'brokenredirects-delete' => '(scryss)',
+'brokenredirects-edit'   => 'reaghey',
+'brokenredirects-delete' => 'scryss',
 
 'withoutinterwiki'        => 'Duillagyn gyn kianglaghyn eddyrwiki',
 'withoutinterwiki-legend' => 'Roie-ockle',
@@ -888,10 +924,10 @@ Bee caghlaaghyn jeant er y duillag shoh as e ghuillag resoonaght ry-akin ayns y
 'changed'                      => 'ceaghlit',
 'created'                      => 'crooit',
 'enotif_anon_editor'           => 'ymmydeyr $1 neuenmyssit',
-'enotif_body'                  => 'Y charrey,
+'enotif_body'                  => '$WATCHINGUSERNAME veen,
 
 
-Va\'n duilag $PAGETITLE er {{SITENAME}} $CHANGEDORCREATED er $PAGEEDITDATE liorish $PAGEEDITOR, jeeagh er $PAGETITLE_URL dys y lhieggan roie dy akin.
+Va\'n duillag $PAGETITLE er {{SITENAME}} $CHANGEDORCREATED er $PAGEEDITDATE liorish $PAGEEDITOR, jeeagh er $PAGETITLE_URL son y lhieggan roie dy akin.
 
 $NEWPAGE
 
@@ -901,14 +937,14 @@ Cur fys er y reagheyder:
 post: $PAGEEDITOR_EMAIL
 wiki: $PAGEEDITOR_WIKI
 
-Cha bee fograghyn elley ayns cah caghlaaghyn elley agh ynrican my vel shiu er jeet dys y duillag shen.
+Cha bee fograghyn elley er caghlaaghyn elley agh my vel shiu er jeet dys y duillag shen ynrican.
 Foddee shiu aajeshaghey bratteeyn ny fograghyn ry hoi dagh duillag er dty rolley arrey.
 
              Dty chorys fograghyn caarjoil ec {{SITENAME}}
 
 --
 Dys kiartee dty rolley arrey y chaghlaa, cur keayrt er
-{{fullurl:{{ns:special}}:Watchlist/edit}}
+{{fullurl:{{#special:Watchlist}}/edit}}
 
 Aaveaghey as cooney s\'odjey:
 {{fullurl:{{MediaWiki:Helppage}}}}',
@@ -920,7 +956,7 @@ Aaveaghey as cooney s\'odjey:
 'exblank'               => "va'n duillag follym",
 'delete-confirm'        => 'Scryss "$1"',
 'delete-legend'         => 'Scryss',
-'historywarning'        => 'Raaue: Ta shennaghys ec y duillag ta shiu er-chee scryssey magh:',
+'historywarning'        => 'Raaue: Ta shennaghys ec y duillag ta shiu er-chee scryssey magh, as mysh $1 {{PLURAL:$1|caghlaa|chaghlaa|chaghlaa|caghlaaghyn}} er:',
 'confirmdeletetext'     => 'Ta shiu er-çhee scryssey magh duillag myrane lesh y shennaghys eck.<br />
 Feeraghey dy vel eh y çhalee ayd eh y yannoo, dy vel ny scanshyn toiggit ayd, as dy vel oo jannoo eh ayns coardailys rish [[{{MediaWiki:Policy-url}}|y pholasee]].',
 'actioncomplete'        => 'Obbraghey creaghnit',
@@ -928,7 +964,7 @@ Feeraghey dy vel eh y çhalee ayd eh y yannoo, dy vel ny scanshyn toiggit ayd, a
 Jeeagh er $2 son recortys ny scryssaghyn magh jeianagh.',
 'deletedarticle'        => '"[[$1]]" scryssit',
 'dellogpage'            => 'Lioar scryssaghyn magh',
-'deletecomment'         => 'Fa son scryssey magh:',
+'deletecomment'         => 'Fa:',
 'deleteotherreason'     => 'Fa elley/tooilley:',
 'deletereasonotherlist' => 'Fa elley',
 'deletereason-dropdown' => '*Fa scryssey cadjin
@@ -939,7 +975,7 @@ Jeeagh er $2 son recortys ny scryssaghyn magh jeianagh.',
 # Rollback
 'rollback_short' => 'Aahogherys',
 'rollbacklink'   => 'aahogherys',
-'editcomment'    => "V'eh \"''\$1''\" giare-choontys y reaghey.", # only shown if there is an edit comment
+'editcomment'    => "V'eh \"''\$1''\" giare-choontys y reaghey.",
 
 # Protect
 'protectlogpage'              => 'Lioar choadee',
@@ -962,7 +998,7 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'protect-expiring'            => 'jerrey jeant ec $1 (UTC)',
 'protect-cascade'             => "Cur fo ghlass ny duillagyn t'ayns y duillag shoh (coadee spooytal)",
 'protect-cantedit'            => 'Cha nod oo caghlaa keim choadey ny duillag shoh.  Cha nel kied ayd ee y reaghey.',
-'protect-expiry-options'      => '1 oor:1 hour,1 laa:1 day,1 hiaghtin:1 week,2 hiaghtin:2 weeks,1 vee:1 month,3 meeghyn:3 months,6 meeghyn:6 months,1 vlein:1 year,neuyerrinagh:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '1 oor:1 hour,1 laa:1 day,1 hiaghtin:1 week,2 hiaghtin:2 weeks,1 vee:1 month,3 meeghyn:3 months,6 meeghyn:6 months,1 vlein:1 year,neuyerrinagh:infinite',
 'restriction-type'            => 'Kied:',
 'restriction-level'           => 'Rea teorey:',
 
@@ -982,7 +1018,7 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'undeletebtn'            => 'Cur er ash',
 'undeletelink'           => 'jeeagh/cur er ash',
 'undeletereset'          => 'Aahoiaghey',
-'undeletecomment'        => 'Cohaggloo:',
+'undeletecomment'        => 'Fa:',
 'undeletedarticle'       => '"[[$1]]" aahoiaghit',
 'undelete-search-box'    => 'Duillagyn scrysst y ronsaghey',
 'undelete-search-submit' => 'Ronsaghey',
@@ -1004,6 +1040,8 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'sp-contributions-newbies'     => 'Taishbyney cohortyssyn liorish coontyssyn noa ynrican',
 'sp-contributions-newbies-sub' => 'Lesh coontyssyn noa',
 'sp-contributions-blocklog'    => 'Lioar chooishyn ghlassaghyn magh',
+'sp-contributions-talk'        => 'resoonaght',
+'sp-contributions-userrights'  => 'Reireydys kiartyn ymmydeyr',
 'sp-contributions-search'      => 'Ronsaghey cohortyssyn',
 'sp-contributions-username'    => 'Enmys IP ny ennym ymmydeyr:',
 'sp-contributions-submit'      => 'Ronsaghey',
@@ -1047,11 +1085,11 @@ Shoh ny reaghaghyn roie da'n duillag '''$1''':",
 'ipbcreateaccount'         => 'Crooaght coontys y chumrail',
 'ipbsubmit'                => 'Glass magh yn ymmydeyr shoh',
 'ipbother'                 => 'Mooad elley am:',
-'ipboptions'               => '2 oor:2 hours,1 laa:1 day,3 laaghyn:3 days,1 hiaghtin:1 week,2 hiaghtin:2 weeks,1 vee:1 month,3 meeghyn:3 months,6 meeghyn:6 months,1 vlein:1 year,neuyerrinagh:infinite', # display1:time1,display2:time2,...
+'ipboptions'               => '2 oor:2 hours,1 laa:1 day,3 laaghyn:3 days,1 hiaghtin:1 week,2 hiaghtin:2 weeks,1 vee:1 month,3 meeghyn:3 months,6 meeghyn:6 months,1 vlein:1 year,neuyerrinagh:infinite',
 'ipbotheroption'           => 'elley',
 'ipbotherreason'           => 'Fa elley/tooilley:',
 'badipaddress'             => 'Enmys IP gyn vree',
-'ipblocklist'              => 'Rolley enmyssyn IP as enmyn ymmydeyr fo ghlass',
+'ipblocklist'              => 'Ymmydeyryn fo ghlass',
 'ipblocklist-username'     => 'Ennym ymmydeyr ny enmys IP:',
 'ipblocklist-submit'       => 'Ronsaghey',
 'blocklistline'            => '$1, $3 er ny g(h)lassey magh ec $2 ($4)',
@@ -1092,7 +1130,7 @@ Foddee oo y duillag resooney y scughey er lheh ny yei shen.",
 'move-watch'              => 'Freill arrey er y duillag shoh',
 'movepagebtn'             => 'Yn duillag y scughey',
 'pagemovedsub'            => "Va'n scughey rahoil",
-'movepage-moved'          => 'Va \'\'\'"$1" aa-enmyssit myr "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => 'Va \'\'\'"$1" aa-enmyssit myr "$2"\'\'\'',
 'articleexists'           => 'Ta duillag ayn lesh yn ennym shen, ny ta ennym mee-chiart reiht ayd.<br />
 Reih ennym elley, my sailliu.',
 'talkexists'              => "'''Va'n duillag hene scughit, agh cha nod y duillag resoonaght y scughey er yn oyr dy row fer ec yn enmys shen hannah.<br />
@@ -1102,7 +1140,7 @@ Jean covestey eddyr oc er laueyn, my sailliu.'''",
 '1movedto2'               => '[[$1]] aa-enmyssit myr [[$2]]',
 '1movedto2_redir'         => 'va [[$1]] scughit dys [[$2]] harrish aaenmys',
 'movelogpage'             => 'Lioar chooishyn y scughey',
-'movereason'              => 'Fa',
+'movereason'              => 'Fa:',
 'revertmove'              => 'goll er ash',
 'delete_and_move'         => 'Scryss as scughey',
 'delete_and_move_confirm' => 'Ta, scryss magh y duillag',
@@ -1154,6 +1192,7 @@ Jean covestey eddyr oc er laueyn, my sailliu.'''",
 'tooltip-search-fulltext'         => 'Ronsaghey ny duillagyn er son y teks shoh',
 'tooltip-p-logo'                  => 'Ard-ghuillag',
 'tooltip-n-mainpage'              => 'Cur keayrt er yn Ard-ghuillag',
+'tooltip-n-mainpage-description'  => 'Cur keayrt er yn ard-ghuillag',
 'tooltip-n-portal'                => "Mychione y çhalee, jean dty chooid share, c'raad reddyn dy feddyn",
 'tooltip-n-currentevents'         => 'Fow oayllys shaghadys fo chooishyn yn laa',
 'tooltip-n-recentchanges'         => "Rolley caghlaaghyn s'noa ayns y wiki.",
@@ -1200,6 +1239,9 @@ T'eh lhiggey da oyr y chur 'sy ghiare-choontey.",
 # Math options
 'mw_math_png' => 'Jean PNG dagh ooilley hraa',
 
+# Math errors
+'math_syntax_error' => 'Co-ordrail marranagh',
+
 # Patrol log
 'patrol-log-auto' => '(seyr-obbragh)',
 'patrol-log-diff' => 'caghlaa $1',
@@ -1243,7 +1285,7 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength", # Do not translate list items
+* focallength",
 
 # EXIF tags
 'exif-imagewidth'       => 'Lheead',
@@ -1291,7 +1333,7 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 'exif-sharpness-1' => 'Bog',
 'exif-sharpness-2' => 'Creoi',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-k' => "Kilometeryn 'syn oor",
 'exif-gpsspeed-m' => "Meeillaghyn 'syn oor",
 
@@ -1339,10 +1381,10 @@ Bee adsyn elley follit dy seyr-obbragh.<br />
 'watchlisttools-raw'  => 'Reaghey aw-rolley arrey',
 
 # Special:Version
-'version'                  => 'Lhieggan', # Not used as normal message but as header for the special page itself
+'version'                  => 'Lhieggan',
 'version-specialpages'     => 'Duillagyn er lheh',
 'version-other'            => 'Elley',
-'version-version'          => 'Lhieggan',
+'version-version'          => '(Lhieggan $1)',
 'version-license'          => 'Kiedoonys',
 'version-software-version' => 'Lhieggan',
 
