@@ -9,6 +9,7 @@
  *
  * @author Dario vet
  * @author Dedee
+ * @author Gastaz
  * @author Malafaya
  * @author Urhixidur
  * @author ZeneizeForesto
@@ -124,16 +125,26 @@ $specialPageAliases = array(
 
 $messages = array(
 # User preference toggles
-'tog-underline'            => 'Sottolineâ i collegamenti',
-'tog-justify'              => 'Alliniamento di paragrafi giustificòu',
-'tog-showtoolbar'          => 'Fâ vedde a barra de strumenti de modìffica (con JavaScript)',
-'tog-rememberpassword'     => "Arregorda a mæ paròlla d'ordine",
-'tog-editwidth'            => 'Spaçio pe cangiâ a larghessa pinn-a',
-'tog-previewontop'         => "Veddi l'anteprimma de d'äto a-o spaçio pe cangiâ",
-'tog-previewonfirst'       => "Veddi l'anteprimma a-o primmo cangiamento",
-'tog-enotifwatchlistpages' => "Fammelo savéi via e-mail quande 'na paggina inta mæ lista in osservassion a va cangiaa.",
-'tog-enotifusertalkpages'  => "Màndime un messaggio e-mail se gh'é de-e modìffiche inta pagina de discuscion da mæ pagina d'utente.",
-'tog-showhiddencats'       => 'Fa vedde e categorîe ascose',
+'tog-underline'               => 'Sottolineâ i collegamenti',
+'tog-highlightbroken'         => 'Evidensia <a href="" class="new">coscì</a> i collegamenti a-e paggine inexisténti (se disattivou: coscì<a href="" class="internal">?</a>)',
+'tog-justify'                 => 'Alliniamento di paragrafi giustificòu',
+'tog-hideminor'               => 'asconde e modifiche minori inte ùrtime modifiche',
+'tog-hidepatrolled'           => 'Ascondi e modifiche verifichè inte ùrtime modifiche',
+'tog-newpageshidepatrolled'   => 'Ascondi e paggine verifiché da-o elenco de paggine ciù reçenti',
+'tog-extendwatchlist'         => 'mostrâ tùtte e modifiche a-i òsserve speciali',
+'tog-usenewrc'                => 'Usâ e ùrtime modifiche avansê (serve Javascript)',
+'tog-numberheadings'          => 'Nùmeraçion aotomàtica di tìtoli de seçión',
+'tog-showtoolbar'             => 'Fâ vedde a barra de strumenti de modìffica (con JavaScript)',
+'tog-editondblclick'          => 'Modifica e paggine co-o dópio clic (serve Javascrpt)',
+'tog-editsection'             => 'Modifica e seçión co-o colegamento [modifica]',
+'tog-editsectiononrightclick' => 'Modifica e seçión co-o clic destro in sciô tìtolo (serve Javascipt)',
+'tog-rememberpassword'        => "Arregorda a mæ paròlla d'ordine",
+'tog-editwidth'               => 'Spaçio pe cangiâ a larghessa pinn-a',
+'tog-previewontop'            => "Veddi l'anteprimma de d'äto a-o spaçio pe cangiâ",
+'tog-previewonfirst'          => "Veddi l'anteprimma a-o primmo cangiamento",
+'tog-enotifwatchlistpages'    => "Fammelo savéi via e-mail quande 'na paggina inta mæ lista in osservassion a va cangiaa.",
+'tog-enotifusertalkpages'     => "Màndime un messaggio e-mail se gh'é de-e modìffiche inta pagina de discuscion da mæ pagina d'utente.",
+'tog-showhiddencats'          => 'Fa vedde e categorîe ascose',
 
 'underline-always' => 'Sempre',
 'underline-never'  => 'Mâi',
@@ -196,27 +207,29 @@ $messages = array(
 'subcategories'                  => 'Sottocategorîe',
 'category-media-header'          => 'Archivvio inta categorîa "$1"',
 'category-empty'                 => "''Pe-o momento 'sta categorîa a no contegne nisciûnn-a paggina ò archivvio multimedia.''",
-'hidden-category-category'       => 'Categorîe ascôse', # Name of the category where hidden categories will be listed
+'hidden-category-category'       => 'Categorîe ascôse',
 'category-subcat-count-limited'  => "'Sta categorîa a contegne {{PLURAL:$1|ûnn-a sottocategorîa, indicaa|$1 sottocategorîe, indicæ}} chì inzû.",
 'category-article-count-limited' => "'Sta categorîa a contegne {{PLURAL:$1|'sta paggina|'ste $1 paggine}}.",
 'listingcontinuesabbrev'         => 'cont.',
 
-'about'          => 'Informaçioin',
-'article'        => 'Pagina de i contenùi',
-'newwindow'      => "(A s'ârve inte 'n âtro barcon)",
-'cancel'         => 'Scassa',
+'about'         => 'Informaçioin',
+'article'       => 'Pagina de i contenùi',
+'newwindow'     => "(A s'ârve inte 'n âtro barcon)",
+'cancel'        => 'Scassa',
+'moredotdotdot' => 'De ciû...',
+'mypage'        => 'A mea pagina',
+'mytalk'        => 'Mæ discuscioin',
+'anontalk'      => 'Discuscion pe questo indirisso IP',
+'navigation'    => 'Navegaçion',
+'and'           => '&#32;e',
+
+# Cologne Blue skin
 'qbfind'         => 'Attrêuva',
 'qbedit'         => 'Cangia',
 'qbpageoptions'  => "Opsioîn de 'sta paggina",
 'qbpageinfo'     => 'Informassion inscia paggina',
 'qbmyoptions'    => 'E mæ paggine',
 'qbspecialpages' => 'Pagine speçiä',
-'moredotdotdot'  => 'De ciû...',
-'mypage'         => 'A mea pagina',
-'mytalk'         => 'Mæ discuscioin',
-'anontalk'       => 'Discuscion pe questo indirisso IP',
-'navigation'     => 'Navegaçion',
-'and'            => '&#32;e',
 
 'errorpagetitle'    => 'Errô',
 'returnto'          => 'Tornâ a $1.',
@@ -256,7 +269,7 @@ $messages = array(
 'otherlanguages'    => 'In ätre lengue',
 'redirectedfrom'    => '(Rediritto da $1)',
 'redirectpagesub'   => 'Paggina de rindirissamento',
-'lastmodifiedat'    => "Sta pagina a l'è stæta cangiâ l'urtima votta a e $2 do $1.", # $1 date, $2 time
+'lastmodifiedat'    => "Sta pagina a l'è stæta cangiâ l'urtima votta a e $2 do $1.",
 'viewcount'         => "'Sta paggina a l'è stæta vista {{PLURAL:$1|solo 'na vòtta|$1 vòtte}}.",
 'protectedpage'     => 'Paggina protezûa',
 'jumpto'            => 'Vanni a:',
@@ -267,7 +280,6 @@ $messages = array(
 'aboutsite'            => 'Informaçioin in scia {{SITENAME}}',
 'aboutpage'            => 'Project:Informassioîn',
 'copyright'            => 'O contegnûo o se peu trovâ a $1.',
-'copyrightpagename'    => "Diritti d'autô de {{SITENAME}}",
 'copyrightpage'        => "{{ns:project}}:Diritti d'autô",
 'currentevents'        => 'Attualitæ',
 'currentevents-url'    => 'Project:Attualitæ',
@@ -321,9 +333,6 @@ $messages = array(
 # General errors
 'error'             => 'Errô',
 'databaseerror'     => 'Errô da a base de i dæti',
-'noconnect'         => "Scûsa! 'Sto scîto o g'ha di problemmi tecnixi e o no pêu connettâse co-a base.<br />
-$1",
-'cachederror'       => "Questa a l'è una copia da pagina ceh ti te çercoö, e a peu esê vegia.",
 'readonly'          => 'Database bloccòu',
 'internalerror'     => 'Errô interno',
 'filecopyerror'     => 'Non ho potùo copiâ o papê "$1" in te "$2".',
@@ -361,16 +370,6 @@ O to account o l'è stæto creoö. Non te ascordà de cangiâ e toe preferençe
 'badretype'                  => "E paròlle d'ordine che t'hæ scrîo son despægie.",
 'userexists'                 => "O nomme d'ûtente inserîo o l'è zà in ûso.<br />
 Pe piaxei prêuva a scellie 'n âtro.",
-'youremail'                  => 'Posta elettronega:',
-'username'                   => "Nomme d'utente",
-'yourrealname'               => 'Nomme vëo:',
-'yourlanguage'               => 'Léngoa:',
-'yourvariant'                => 'Differensa',
-'yournick'                   => 'Nommeaggio:',
-'badsig'                     => 'Errô in ta firma; controlla i comandi HTML.',
-'badsiglength'               => "O nommeaggio o l'é tròppo lóngo; o dêve avéi meno de $1 caratteri.",
-'email'                      => 'Posta elettronega',
-'prefs-help-realname'        => '* Nomme vëo (opsionâ): se o se scellie de scrivilo, o sajà dêuviòu pe ascrivighe a paternitæ di contegnûi inviæ.',
 'loginerror'                 => "Errô inte l'accesso",
 'noname'                     => "O nomme d'ûtente o l'è sballiòu.",
 'loginsuccesstitle'          => 'Accesso effettuòu',
@@ -385,7 +384,7 @@ A dêve contegnî mìnimo $1 caratteri e esse diverza da-o teu nómme utente.",
 'mailmypassword'             => "Inviâ paròlla d'ordine (password) via e-mail",
 'passwordremindertitle'      => "Servissio Password Reminder (nêuva paròlla d'ordine temporannia) de {{SITENAME}}",
 'passwordremindertext'       => "Quarchedûn (probabilmente ti, con indirisso IP \$1) o g'ha domandòu l'invîo de 'na nêuva paròlla d'ordine pe l'accesso a {{SITENAME}} (\$4).
-A paròlla d'ordine pe l'ûtente \"\$2\" a l'è stæta impostâa a \"\$3\". 
+A paròlla d'ordine pe l'ûtente \"\$2\" a l'è stæta impostâa a \"\$3\".
 O se conseggia de fâ l'accesso quanto primma e cangiâ a paròlla d'ordine immediatamente.
 Se no ti è stæto ti a fâ 'sta domanda, oppûre se ti g'hæ ritrovòu a têu paròlla d'ordine e no ti vêu cangiâla ciû, ti pêu ignorâ 'sto messaggio e andâ avanti ûsando a vegia paròlla d'ordine.",
 'noemail'                    => 'No gh\'è nisciûn indirisso e-mail registròu pe l\'ûtente "$1".',
@@ -430,18 +429,18 @@ Pe abilitâ l'invîo de messaggi e-mail pe quest'accesso, o se deive seguî l'is
 'hr_tip'          => 'Linnia orissontâ',
 
 # Edit pages
-'summary'                => 'Oggetto:',
-'subject'                => 'Argomento (tittolo):',
-'minoredit'              => 'Cangiamento minô (m)',
-'watchthis'              => 'Azzonze a-i osservæ speçiâli',
-'savearticle'            => 'Sârva a pagina',
-'preview'                => 'Anteprimma',
-'showpreview'            => "Veddi l'anteprimma",
-'showdiff'               => 'Veddi i cangiamenti',
-'anoneditwarning'        => "'''Attension:''' No ti t'hæ registròu. O têu indirisso IP o sajà misso inta stöja di cangiamenti da paggina.",
-'summary-preview'        => 'Anteprimma oggetto:',
-'blockedtitle'           => "L'utente o l'é bloccòu",
-'blockedtext'            => "''''Sto nomme d'ûtente ou indirisso IP o l'è stæto bloccòu.'''
+'summary'                    => 'Oggetto:',
+'subject'                    => 'Argomento (tittolo):',
+'minoredit'                  => 'Cangiamento minô (m)',
+'watchthis'                  => 'Azzonze a-i osservæ speçiâli',
+'savearticle'                => 'Sârva a pagina',
+'preview'                    => 'Anteprimma',
+'showpreview'                => "Veddi l'anteprimma",
+'showdiff'                   => 'Veddi i cangiamenti',
+'anoneditwarning'            => "'''Attension:''' No ti t'hæ registròu. O têu indirisso IP o sajà misso inta stöja di cangiamenti da paggina.",
+'summary-preview'            => 'Anteprimma oggetto:',
+'blockedtitle'               => "L'utente o l'é bloccòu",
+'blockedtext'                => "''''Sto nomme d'ûtente ou indirisso IP o l'è stæto bloccòu.'''
 
 O blòcco o l'è stæto fæto da \$1. A raxon dæta a l'è ''\$2''.
 
@@ -453,7 +452,7 @@ O l'è poscibbile contattâ \$1 o 'n âtro [[{{MediaWiki:Grouppage-sysop}}|ammin
 O no se pêu ûsâ o comando \"Inviâ 'na léttia elettronega a quest'ûtente\" se ti no ti g'hæ 'n indirisso e-mail registròu inte têu [[Special:Preferences|preferense]] e se o no l'è stæto bloccòu ascì.
 O têu indirisso IP o l'è \$3, e o têu blòcco ID o l'è #\$5.
 Pe piaxei mettighe ûn di doî in tûtte e domande che ti fæ.",
-'autoblockedtext'        => "O têu indirisso IP o l'è stæto bloccòu outomaticamente perché o l'ea za ûsòu da 'n âtro ûtente, bloccòu da \$1.
+'autoblockedtext'            => "O têu indirisso IP o l'è stæto bloccòu outomaticamente perché o l'ea za ûsòu da 'n âtro ûtente, bloccòu da \$1.
 A raxon dæta a l'è stæta:
 
 :''\$2''
@@ -461,45 +460,45 @@ A raxon dæta a l'è stæta:
 * Inissio do blòcco: \$8
 * Fin do blòcco: \$6
 
-Ti pêu contattâ \$1 ou 'n âtro 
+Ti pêu contattâ \$1 ou 'n âtro
 [[{{MediaWiki:Grouppage-sysop}}|amministratô]] pe parlâ inscio blòcco.
 
 Dagghe a mente a che no ti pêu ûsâ o comando \"manda na littia elettronega a sto utente\" se non ti g'hæ 'n indirisso de posta elettronega registroö in te têu [[Special:Preferences|preferense]] e se o no l'è stæto bloccòu ascì.
 
 O têu blòcco ID o l'è \$5. Pe piaxei metti 'sto ID in tûtte e domande che ti fæ.",
-'blockedoriginalsource'  => "A fònte de '''$1''' a l'è chi sotta:",
-'blockededitsource'      => "O testo de i '''teu cangiamenti''' a '''$1''' o l'è chi sotta:",
-'whitelistedittitle'     => "Bezêugna registrâse pe modificâ 'na pagina.",
-'whitelistedittext'      => 'Pe cangia sta pagina devvi $1.',
-'loginreqtitle'          => "Besêugna registrâse primma de modificâ 'sta paggina.",
-'accmailtitle'           => 'Pòula segretta spedïa',
-'accmailtext'            => 'A pòula segretta pe-o utente "$1" a l\'è stæta spedïa a o indirisso $2.',
-'newarticle'             => '(Nêuvo)',
-'newarticletext'         => "'Sto collegamento o corisponde a 'na paggina che ancon a no l'esciste.
+'blockedoriginalsource'      => "A fònte de '''$1''' a l'è chi sotta:",
+'blockededitsource'          => "O testo de i '''teu cangiamenti''' a '''$1''' o l'è chi sotta:",
+'whitelistedittitle'         => "Bezêugna registrâse pe modificâ 'na pagina.",
+'whitelistedittext'          => 'Pe cangia sta pagina devvi $1.',
+'loginreqtitle'              => "Besêugna registrâse primma de modificâ 'sta paggina.",
+'accmailtitle'               => 'Pòula segretta spedïa',
+'accmailtext'                => 'A pòula segretta pe-o utente "$1" a l\'è stæta spedïa a o indirisso $2.',
+'newarticle'                 => '(Nêuvo)',
+'newarticletext'             => "'Sto collegamento o corisponde a 'na paggina che ancon a no l'esciste.
 
 Se o se vêu creâ a paggina òua, o se pêu comensâ a scrive o testo into spassio vêuo chì sotta.
 (fâ riferimento a-e [[{{MediaWiki:Helppage}}|paggine d'agiûtto]] pe ciû informassion).
 
 Se o s'ha intròu inte 'sto collegamento pe sbàllio, o basta sciaccâ '''Inderrê''' (Indietro) into navigatô.",
-'noarticletext'          => "Inte 'sto momento a paggina çercâa a l'è vêua. O l'è poscibbile [[Special:Search/{{PAGENAME}}|çercâ 'sto tittolo]] inte âtre paggine do scîto oppûre [{{fullurl:{{FULLPAGENAME}}|action=edit}} modificâ a paggina òua].",
-'previewnote'            => "'''Questa chì a l'è solo 'n'anteprimma; i cangiamenti no son ancon stæti sarvæ!'''",
-'editing'                => 'Modiffica de $1',
-'editingsection'         => 'Modiffica de $1 (session)',
-'yourtext'               => 'O teu testo',
-'yourdiff'               => 'Differense',
-'copyrightwarning'       => "Nota: Tùtte e contribuçioìn a {{SITENAME}} van conscideræ comme rilasciæ drento a-i termini da licensa d'ûso $2 (veddi $1 pe savéine de ciù).
+'noarticletext'              => "Inte 'sto momento a paggina çercâa a l'è vêua. O l'è poscibbile [[Special:Search/{{PAGENAME}}|çercâ 'sto tittolo]] inte âtre paggine do scîto oppûre [{{fullurl:{{FULLPAGENAME}}|action=edit}} modificâ a paggina òua].",
+'previewnote'                => "'''Questa chì a l'è solo 'n'anteprimma; i cangiamenti no son ancon stæti sarvæ!'''",
+'editing'                    => 'Modiffica de $1',
+'editingsection'             => 'Modiffica de $1 (session)',
+'yourtext'                   => 'O teu testo',
+'yourdiff'                   => 'Differense',
+'copyrightwarning'           => "Nota: Tùtte e contribuçioìn a {{SITENAME}} van conscideræ comme rilasciæ drento a-i termini da licensa d'ûso $2 (veddi $1 pe savéine de ciù).
 Se no ti veu che i testi teu pêuan esse modificæ da quarchedùn sensa limitaçioìn, no mandâli a {{SITENAME}}.<br />
 Inviando o testo ti diciâri, sott'a teu responsabilitæ, ch'o l'é stæto scrîto da ti personalmente oppure ch'o l'é stæto piggiòu da 'na fonte de pùbrico domìnio òu anàlogamente lìbea.<br />
 '''NO INVIÂ MATERIÂLE COVERTO DA DRÎTI D'AUTÔ SENSA OUTORIZAÇION!'''",
-'longpagewarning'        => "'''ATTENSION: 'Sta paggina chì a g'ha $1 kilobyte; çerti browser porieivan avei di problemmi inta modiffica de-e paggine che s'avvixinn-an o che ecceddan i 32 kB.
+'longpagewarning'            => "'''ATTENSION: 'Sta paggina chì a g'ha $1 kilobyte; çerti browser porieivan avei di problemmi inta modiffica de-e paggine che s'avvixinn-an o che ecceddan i 32 kB.
 Pe piaxei conscidera l'opportûnitæ de soddividde a paggina in sessioîn ciû piccinn-e.'''",
-'templatesused'          => "Template dêuviæ inte 'sta paggina:",
-'templatesusedpreview'   => "Template dêuviæ inte 'st'anteprimma:",
-'template-protected'     => '(protezûo)',
-'template-semiprotected' => '(semiprotezûo)',
-'nocreatetext'           => "A poscibilitæ de creâ nêuve paggine insce {{SITENAME}} a l'è stæta limitâ solo a-i ûtenti registræ.
+'templatesused'              => "Template dêuviæ inte 'sta paggina:",
+'templatesusedpreview'       => "Template dêuviæ inte 'st'anteprimma:",
+'template-protected'         => '(protezûo)',
+'template-semiprotected'     => '(semiprotezûo)',
+'nocreatetext'               => "A poscibilitæ de creâ nêuve paggine insce {{SITENAME}} a l'è stæta limitâ solo a-i ûtenti registræ.
 O se pêu tornâ inderê e modificâ 'na paggina escistente, oppûre [[Special:UserLogin|intrâ ò creâ 'n accesso nêuvo]].",
-'recreate-deleted-warn'  => "'''Attension: o se sta pe ricreâ 'na paggina zà scassâa into passòu.'''
+'recreate-moveddeleted-warn' => "'''Attension: o se sta pe ricreâ 'na paggina zà scassâa into passòu.'''
 
 O se deive consciderâ se o l'è davvei corretto continuâ avanti a modificâ 'sta paggina.
 E relative cancellassioîn son pûbricæ chì sotta:",
@@ -514,7 +513,7 @@ A razon dæta a l'è ''$2''",
 'viewpagelogs'        => "Veddi i log relativi a 'sta paggina.",
 'currentrev'          => 'Verscion attuâle',
 'revisionasof'        => 'Verscion do $1',
-'revision-info'       => 'Verscion do $1, outô: $2', # Additionally available: $3: revision id
+'revision-info'       => 'Verscion do $1, outô: $2',
 'previousrevision'    => '← Verscion meno reçente',
 'nextrevision'        => 'Revixon ciû nêuva →',
 'currentrevisionlink' => 'Ûrtima revixon',
@@ -532,7 +531,7 @@ Leggenda: (corr) = differense co-a verscion corrente, (prec) = differense co-a v
 
 # Revision feed
 'history-feed-title'          => 'Stöia de e revisioin',
-'history-feed-item-nocomment' => '$1 o $2', # user at time
+'history-feed-item-nocomment' => '$1 o $2',
 
 # Diffs
 'history-title'           => 'Cronologîa de-e revixoîn de "$1"',
@@ -546,27 +545,35 @@ Leggenda: (corr) = differense co-a verscion corrente, (prec) = differense co-a v
 'searchresults'         => 'Resultati da reçerca',
 'searchsubtitle'        => "Ti t'è çercoö '''[[:$1]]'''",
 'searchsubtitleinvalid' => "Ti t'è çercoö '''$1'''",
-'noexactmatch'          => "'''No gh'è nisciûnn-a paggina c'a se ciamme \"\$1\".''' O se pêu [[:\$1|creâla òua]].",
-'prevn'                 => 'Preçedenti $1',
-'nextn'                 => 'Proscima $1',
-'viewprevnext'          => 'Veddi ($1) ($2) ($3).',
+'prevn'                 => 'Preçedenti {{PLURAL:$1|$1}}',
+'nextn'                 => 'Proscima {{PLURAL:$1|$1}}',
+'viewprevnext'          => 'Veddi ($1 {{int:pipe-separator}} $2) ($3).',
 'searchhelp-url'        => 'Help:Contegnûi',
 'powersearch'           => 'Çerca',
 
 # Preferences page
-'preferences'       => 'Preferençe',
-'mypreferences'     => 'Mæ preferense',
-'changepassword'    => 'Cangiâ a pòula segretta',
-'skin-preview'      => 'Anteprimma',
-'dateformat'        => 'Formato da a data',
-'datetime'          => 'Data e oùa',
-'saveprefs'         => 'Sarva',
-'textboxsize'       => 'Cangia',
-'searchresultshead' => 'Çerca',
-'timezonelegend'    => 'Oùa',
-'allowemail'        => 'Permitti a posta elettronega da ätri utenti',
-'default'           => 'Predefinïo',
-'files'             => 'Papê',
+'preferences'         => 'Preferençe',
+'mypreferences'       => 'Mæ preferense',
+'changepassword'      => 'Cangiâ a pòula segretta',
+'skin-preview'        => 'Anteprimma',
+'prefs-datetime'      => 'Data e oùa',
+'saveprefs'           => 'Sarva',
+'prefs-editing'       => 'Cangia',
+'searchresultshead'   => 'Çerca',
+'timezonelegend'      => 'Oùa',
+'allowemail'          => 'Permitti a posta elettronega da ätri utenti',
+'default'             => 'Predefinïo',
+'prefs-files'         => 'Papê',
+'youremail'           => 'Posta elettronega:',
+'username'            => "Nomme d'utente",
+'yourrealname'        => 'Nomme vëo:',
+'yourlanguage'        => 'Léngoa:',
+'yourvariant'         => 'Differensa',
+'yournick'            => 'Nommeaggio:',
+'badsig'              => 'Errô in ta firma; controlla i comandi HTML.',
+'badsiglength'        => "O nommeaggio o l'é tròppo lóngo; o dêve avéi meno de $1 caratteri.",
+'email'               => 'Posta elettronega',
+'prefs-help-realname' => '* Nomme vëo (opsionâ): se o se scellie de scrivilo, o sajà dêuviòu pe ascrivighe a paternitæ di contegnûi inviæ.',
 
 # Groups
 'group-user' => 'Ûtenti',
@@ -601,6 +608,8 @@ Leggenda: (corr) = differense co-a verscion corrente, (prec) = differense co-a v
 
 # Recent changes linked
 'recentchangeslinked'          => 'Cangiamenti correlæ',
+'recentchangeslinked-feed'     => 'Cangiamenti correlæ',
+'recentchangeslinked-toolbox'  => 'Cangiamenti correlæ',
 'recentchangeslinked-title'    => 'Modiffiche correlæ a "$1"',
 'recentchangeslinked-noresult' => 'Nisciûn cangiamento a-e paggine collegæ into periodo speçificòu.',
 'recentchangeslinked-summary'  => "'Sta paggina a fa vedde e modiffiche ciû reçenti a-e paggine in collegamento.
@@ -620,15 +629,15 @@ E paggine in osservassion son dipinte in '''grascietto'''.",
 'savefile'             => 'Sarva o papê',
 'uploadedimage'        => 'O s\'ha caregòu "[[$1]]"',
 'uploaddisabledtext'   => 'In {{SITENAME}} non se peu caregâ de papê.',
-'uploadcorrupt'        => "O papê o gh'à di erroì ò-o gh'à unn'estenscion sbaliâ. Pe piaxei dagghe unn'euggiâ a-o papê e càreghilo tórna.",
 'uploadvirus'          => 'O papê gha un virus!! Dettaggi: $1',
 'sourcefilename'       => "Nomme do papê d'origine:",
 'destfilename'         => 'Nomme do papê de destin:',
 
 'upload-file-error' => 'Errô interno',
 
-'license'   => 'Permisso:',
-'nolicense' => 'Nisciûnn-a liçensa indicâa',
+'license'        => 'Permisso:',
+'license-header' => 'Permisso:',
+'nolicense'      => 'Nisciûnn-a liçensa indicâa',
 
 # Special:ListFiles
 'listfiles_search_for' => "Çerca pe nomme de l'imàgine:",
@@ -637,6 +646,7 @@ E paggine in osservassion son dipinte in '''grascietto'''.",
 'listfiles_date'       => 'Dæta',
 
 # File description page
+'file-anchor-link'          => 'Archivvio',
 'filehist'                  => "Cronologîa de l'archivvio",
 'filehist-help'             => "Sciacca inscie 'n grûppo data/ôa pe vedde l'archivvio comme o se presentâva into momento indicòu.",
 'filehist-current'          => 'Corrente',
@@ -648,10 +658,7 @@ E paggine in osservassion son dipinte in '''grascietto'''.",
 'imagelinks'                => "Collegamenti a l'immaggine",
 'linkstoimage'              => "Queste son e pagine che appóntan a st'archivio",
 'nolinkstoimage'            => "No gh'è nisciûnn-a paggina collegâa con 'st'archivvio.",
-'sharedupload'              => "'St'archivvio o l'è condiviso; sajeiva a dî c'o pêu ese dêuviòu da ciû progetti wiki.", # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'shareduploadwiki-linktext' => 'pagina da descriçion do papê',
-'noimage'                   => "No gh'è nisciûn archivvio con quello nomme, o se pêu $1.",
-'noimage-linktext'          => 'Caregâlo òua',
+'sharedupload'              => "'St'archivvio o l'è condiviso; sajeiva a dî c'o pêu ese dêuviòu da ciû progetti wiki.",
 'uploadnewversion-linktext' => "Carega 'na nêuva verscion de 'st'archivvio chì",
 
 # File deletion
@@ -681,8 +688,8 @@ E paggine in osservassion son dipinte in '''grascietto'''.",
 
 'brokenredirects'        => 'Rindirissamenti sballiæ',
 'brokenredirectstext'    => 'De sotta unn-a lista de reindirissi a pagine che non existàn:',
-'brokenredirects-edit'   => '(cangia)',
-'brokenredirects-delete' => '(scassa)',
+'brokenredirects-edit'   => 'cangia',
+'brokenredirects-delete' => 'scassa',
 
 'withoutinterwiki'         => 'Paggine sensa interwiki',
 'withoutinterwiki-summary' => "'Ste paggine chì inzû no g'han nisciûn collegamento co-e verscioîn in âtre lengoe:",
@@ -809,7 +816,7 @@ Ti te peu strinza a vista se ti te çerni un tipo de registro, un nomme de un ut
 'deletedtext'           => 'A paggina "<nowiki>$1</nowiki>" a l\'è stæta scassâa. Consûltâ o $2 pe \'na lista de-e paggine scassæ de reçente.',
 'deletedarticle'        => 'O s\'ha scassòu "[[$1]]"',
 'dellogpage'            => 'Registro de-e cose scassæ',
-'deletecomment'         => 'Raxon pe scassâ',
+'deletecomment'         => 'Raxon:',
 'deleteotherreason'     => 'Ûn âtro motivo',
 'deletereasonotherlist' => "Ûnn'âtra raxon",
 
@@ -817,21 +824,20 @@ Ti te peu strinza a vista se ti te çerni un tipo de registro, un nomme de un ut
 'rollbacklink'  => 'rollback',
 'cantrollback'  => "O no se pêu tornâ inderê; l'ûtente ch'à fæto quelle modiffiche o l'è stæto l'ûnico contribûente.",
 'alreadyrolled' => "O no se peû tornâ inderê a-i ûrtimi cangiamenti da pagina [[:$1]]
-da [[User:$2|$2]] ([[User talk:$2|Ciæti]]); quarche âtro 
+da [[User:$2|$2]] ([[User talk:$2|Ciæti]]); quarche âtro
 o l'à cangiâ ò o l'è zà tornòu inderê.
 L'ûrtimo cangiamento o ghe l'à fæto [[User:$3|$3]] ([[User talk:$3|Ciæti]]).",
-'revertpage'    => 'E modificaçioin de [[Special:Contributions/$2|$2]] ([[User talk:$2|Ciæti]]) son stæte eliminæ; riportæ a verscion de primma de [[User:$1|$1]]', # Additionally available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'revertpage'    => 'E modificaçioin de [[Special:Contributions/$2|$2]] ([[User talk:$2|Ciæti]]) son stæte eliminæ; riportæ a verscion de primma de [[User:$1|$1]]',
 
 # Protect
 'protectlogpage'              => 'Protessioîn',
 'protectedarticle'            => 'o s\'ha protezûo "[[$1]]"',
 'prot_1movedto2'              => '[[$1]] mesciòu a [[$2]]',
 'protect-legend'              => 'Confermâ protession',
-'protectcomment'              => 'Motivo da protession:',
+'protectcomment'              => 'Raxon:',
 'protectexpiry'               => 'Scadensa:',
 'protect_expiry_invalid'      => 'Scadensa invalida.',
 'protect_expiry_old'          => 'Data de scadensa into passòu.',
-'protect-unchain'             => 'Scollegâ i permissi de stramûo',
 'protect-text'                => "Chì o l'è poscibbile vedde e modificâ o livello de protession pe-a paggina '''<nowiki>$1</nowiki>'''.",
 'protect-locked-access'       => "No ti g'hæ permisso pe modificâ i livelli de protession da paggina.
 Queste son e impostassioîn correnti pe 'sta paggina ('''$1'''):",
@@ -844,7 +850,7 @@ Queste son e impostassioîn correnti pe 'sta paggina ('''$1'''):",
 'protect-expiring'            => 'scadensa: $1 (UTC)',
 'protect-cascade'             => 'Protession recorsciva (estende a protession a tûtte e paggine inclûse in questa chì).',
 'protect-cantedit'            => "Ti no ti pêu modificâ i livelli de protession pe-a paggina se no ti g'hæ i permissi pe modificâ a paggina mæxima.",
-'protect-expiry-options'      => '2 ôe:2 hours,1 giorno:1 day,3 giorni:3 days,1 settemann-a:1 week,2 settemann-e:2 weeks,1 meise:1 month,3 meixi:3 months,6 meixi:6 months,1 anno:1 year,infinîo:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '2 ôe:2 hours,1 giorno:1 day,3 giorni:3 days,1 settemann-a:1 week,2 settemann-e:2 weeks,1 meise:1 month,3 meixi:3 months,6 meixi:6 months,1 anno:1 year,infinîo:infinite',
 'restriction-type'            => 'Permisso',
 'restriction-level'           => 'Livello de restrission',
 
@@ -881,6 +887,7 @@ $1',
 
 'sp-contributions-newbies-sub' => 'Pe i nêuvi ûtenti',
 'sp-contributions-blocklog'    => 'Blocchi',
+'sp-contributions-talk'        => 'Ciæti',
 'sp-contributions-submit'      => 'Çerca',
 
 # What links here
@@ -896,8 +903,8 @@ $1',
 
 # Block/unblock
 'blockip'                     => "Blocca l'ûtente",
-'ipbreason'                   => 'Raxon do blòcco:',
-'ipboptions'                  => '2 ôe:2 hours,1 giorno:1 day,3 giorni:3 days,1 settemann-a:1 week,2 settemann-e:2 weeks,1 meise:1 month,3 meixi:3 months,6 meixi:6 months,1 anno:1 year,infinîo:infinite', # display1:time1,display2:time2,...
+'ipbreason'                   => 'Raxon:',
+'ipboptions'                  => '2 ôe:2 hours,1 giorno:1 day,3 giorni:3 days,1 settemann-a:1 week,2 settemann-e:2 weeks,1 meise:1 month,3 meixi:3 months,6 meixi:6 months,1 anno:1 year,infinîo:infinite',
 'badipaddress'                => 'Indirisso IP non valido',
 'blockipsuccesssub'           => 'Affermaçion arriescïa',
 'blockipsuccesstext'          => "[[Special:Contributions/$1|$1]] o l'è stæto affermoö.
@@ -973,8 +980,6 @@ Inte 'sti câxi, se o se vêu fâ coscì, o se deive stramûâ ò azzonze manual
 'allmessagescurrent'        => 'Testo corrente',
 'allmessagestext'           => "Sta chie a l'è unn-a lista de messaggi do scistema in ta MediaWiki.",
 'allmessagesnotsupportedDB' => "'''{{ns:special}}:Allmessages''' o non ti te peu vedde, perchè '''\$wgUseDatabaseMessages''' o non l'è attivo.",
-'allmessagesfilter'         => 'Çernia de mesasggi:',
-'allmessagesmodified'       => 'Vanni vedde söo i cangiamenti',
 
 # Thumbnails
 'thumbnail-more'           => 'Ciû grande',
@@ -1032,7 +1037,7 @@ Inte 'sti câxi, se o se vêu fâ coscì, o se deive stramûâ ò azzonze manual
 
 # Attribution
 'anonymous'        => 'Utente anonimmo de {{SITENAME}}',
-'lastmodifiedatby' => "Sta pagina a l'è stæta cangiâ l'urtima votta a e $2 do $1 da $3.", # $1 date, $2 time, $3 user
+'lastmodifiedatby' => "Sta pagina a l'è stæta cangiâ l'urtima votta a e $2 do $1 da $3.",
 
 # Browsing diffs
 'previousdiff' => '← Differensa preçedente',
@@ -1069,7 +1074,7 @@ L'ingançi succescivi, inscia mæxima riga, van conscideræ comme eccescioîn (p
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength", # Do not translate list items
+* focallength",
 
 # EXIF tags
 'exif-datetime'   => 'Data e öa do cangiamento do papê',
@@ -1117,7 +1122,7 @@ L'ingançi succescivi, inscia mæxima riga, van conscideræ comme eccescioîn (p
 'watchlisttools-raw'  => 'Modiffica a lista in formato testo',
 
 # Special:Version
-'version' => 'Verscion', # Not used as normal message but as header for the special page itself
+'version' => 'Verscion',
 
 # Special:SpecialPages
 'specialpages' => 'Paggine speçiâli',
