@@ -1,7 +1,7 @@
 #!/bin/bash
 # MediaWiki	(http://www.mediawiki.org/wiki/MediaWiki)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-07-29
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-03
 # require:
 # require:
 #	httpd-2.2.x
@@ -10,14 +10,14 @@
 #	textsearch_ja-8.4.x
 #	mecab-0.97, ipadic-0.9.2
 #
-VERSION=1.15.5
+VERSION=1.16.4
 M_VER=${VERSION%%\.?}
 echo $M_VER
 SRC_URI="http://download.wikimedia.org/mediawiki/$M_VER/mediawiki-${VERSION}.tar.gz"
-#(for example: http://download.wikimedia.org/mediawiki/1.15/mediawiki-1.15.4.tar.gz)
+#(for example: http://download.wikimedia.org/mediawiki/1.16/mediawiki-1.16.4.tar.gz)
 
 BLDOC=
-BLDOC=1
+#BLDOC=1
 
 REL=P1
 
@@ -67,7 +67,7 @@ cd $WORK
 mkdir -p install
 sed -e "s/VERSION/$VERSION/g" \
     -e "s/_PACKAGENAME_/${PAC_NAME}-${SYS_NAME}/g" \
-    $CUSTOM_DIR/doinst.sh-15 > install/doinst.sh
+    $CUSTOM_DIR/doinst.sh-16 > install/doinst.sh
 
 
 mkdir -p opt/htdocs
@@ -78,10 +78,12 @@ cd $PAC_NAME
 
 sed -e 's/wikiuser/www/' \
     -e 's/localhost/127.0.0.1/' \
-    -e 's/wikidb/wikidb15/' \
+    -e 's/wikidb/wikidb16/' \
+    -e 's/"en"/"ja"/' \
+    -e 's/"Shm", "none"/"Shm", "apc"/' \
     -e '/MEDIAWIKI_INSTALL/a define( "TEXTSEARCH_COMPAT", true );' \
-    config/index.php > config/index.php.new || exit 1
-mv -v  config/index.php.new  config/index.php
+    config/Installer.php > config/Installer.php.new || exit 1
+mv -v  config/Installer.php.new  config/Installer.php
 sed -e "s%(\$this->numeric_version >= 8.3)%(\$this->numeric_version >= 8.3 \&\&  ( defined('TEXTSEARCH_COMPAT') \&\& TEXTSEARCH_COMPAT != true ))%" \
     includes/db/DatabasePostgres.php > includes/db/DatabasePostgres.php.new || exit 1
 mv -v includes/db/DatabasePostgres.php.new includes/db/DatabasePostgres.php
@@ -138,10 +140,10 @@ __EOCL__
 cd $WORK
 echo "y
 1
-" | makepkg ${PAC_NAME}.tgz
+" | makepkg ${PAC_NAME}-${SYS_NAME}.tgz
 
 echo -n "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz"
-if `mv -v ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
+if `mv -v ${PAC_NAME}-${SYS_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
   echo " ... done"
 else
   echo " ... false"
